package gui;

import java.awt.EventQueue;

import javax.swing.JFrame;
import java.awt.GridLayout;
import javax.swing.JPanel;

import java.awt.Color;
import java.awt.Component;
import java.awt.Container;
import java.awt.Cursor;
import java.awt.Dimension;
import java.awt.FlowLayout;
import java.awt.Font;
import java.awt.GridBagLayout;
import java.awt.GridBagConstraints;
import java.awt.Insets;
import java.awt.Point;

import javax.swing.Box;
import javax.swing.GroupLayout;
import javax.swing.GroupLayout.Alignment;
import javax.swing.Icon;
import javax.swing.JCheckBox;
import javax.swing.JComponent;
import javax.swing.JFileChooser;
import javax.swing.JSeparator;
import javax.swing.LayoutStyle.ComponentPlacement;
import javax.swing.BoxLayout;
import javax.swing.JScrollPane;
import javax.swing.JTextArea;
import javax.swing.JTabbedPane;
import javax.swing.SwingConstants;
import javax.swing.SwingUtilities;
import javax.swing.SwingWorker;
import javax.swing.UIManager;
import javax.swing.UnsupportedLookAndFeelException;

import java.awt.BorderLayout;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.ItemEvent;
import java.awt.event.ItemListener;
import java.beans.PropertyChangeEvent;
import java.beans.PropertyChangeListener;
import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.File;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.Properties;
import java.util.logging.Handler;
import java.util.logging.Level;
import java.util.logging.Logger;

import javax.swing.JButton;
import javax.swing.JLabel;
import javax.swing.JTextField;
import javax.swing.border.TitledBorder;
import javax.swing.event.DocumentEvent;
import javax.swing.event.DocumentListener;
import javax.swing.filechooser.FileFilter;
import javax.swing.text.DefaultCaret;

import scan.Scanner;
import scan.UsbConfig;


public class MultiScanGUI {
	private Logger log=Logger.getLogger(this.getClass().getName());
	List<Scanner> scanners;
	List<ScannerPanel> scannerPanels;
	List<ScanWorker> workers;
	Thread scanThread;
	boolean resetAll;
	
	int scannersActive;
	int nextPlateNr;
	
	UsbConfig usbCfg;
	String cfgPath;
	final private String newline=System.getProperty("line.separator");
	private JFrame frame;
	private JTextArea logArea;

	private LedLight ledMonitor;
	private JCheckBox[] chkRow;
	private JButton btnReset;
	private JButton btnExit;
	private JButton btnScan;
	private JButton btnFolderChoose;
	private JTextField txtFolder;
	private JTextField txtPrefix;
	
	/**
	 * Launch the application.
	 */
//	public static void main(String[] args) {
//		EventQueue.invokeLater(new Runnable() {
//			public void run() {
//				try {
//					MultiScanGUI window = new MultiScanGUI();
//					window.frame.setVisible(true);
//				} catch (Exception e) {
//					e.printStackTrace();
//				}
//			}
//		});
//	}

	/**
	 * Create the application.
	 */
	public MultiScanGUI(String cfgPath) {
		//			// look and feel
		//			try {
		//				// Set System L&F
		//				UIManager.setLookAndFeel(
		//						UIManager.getSystemLookAndFeelClassName());
		//			} 
		//			catch (UnsupportedLookAndFeelException e) {
		//				// handle exception
		//			}
		//			catch (ClassNotFoundException e) {
		//				// handle exception
		//			}
		//			catch (InstantiationException e) {
		//				// handle exception
		//			}
		//			catch (IllegalAccessException e) {
		//				// handle exception
		//			}
		//			
		this.cfgPath=cfgPath;
		this.nextPlateNr=1;
		this.scannerPanels=new ArrayList<ScannerPanel>();
		this.resetAll=false;
		
		initializeFrame();
		Logger topLogger=Logger.getLogger("");

		TextAreaHandler handler=TextAreaHandler.getInstance();
		handler.setTextArea(logArea);
		handler.setLevel(Level.ALL);
		handler.setFormatter(new LogFormatter());

		
		boolean handlerIsSet=false;
		Handler[] curHandlers=topLogger.getHandlers();
		for(Handler h:curHandlers){
			if(h instanceof TextAreaHandler){
				handlerIsSet=true;
			}
		}
		if(!handlerIsSet)
			topLogger.addHandler(handler);


		log=Logger.getLogger(this.getClass().getName());
//		log.info("test");

		dispatcher();
//		log.info("test2");
	}


	/**
	 * Initialize the contents of the frame.
	 */
	private void initializeFrame(){
		frame = new JFrame("MultiScan V1.1");
		frame.setBounds(100, 100, 700, 700);
		frame.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
		frame.getContentPane().setLayout(new BoxLayout(frame.getContentPane(),BoxLayout.Y_AXIS));

		JPanel pnlMain = new JPanel();
		frame.getContentPane().add(pnlMain);
		pnlMain.setLayout(new GridBagLayout());
		pnlMain.setPreferredSize(new Dimension(700,420));
//		pnlMain.setMaximumSize(new Dimension(800,Short.MAX_VALUE));

		GridBagConstraints gbc=new GridBagConstraints();
		gbc.weightx=1.0;
		gbc.weighty=1.0;
		gbc.fill=GridBagConstraints.BOTH;
		for(int i=0;i<8;++i){
			gbc.gridx=i/4;
			gbc.gridy=i%4;
			ScannerPanel sp=new ScannerPanel(i+1);
//			if(scanners.get(i)==null){
//				sp.setActive(false);
//			}
//			sp.setNextPlateNr(nextPlateNr);
//			nextPlateNr++;
			sp.addItemListener(new CheckBoxHandler());
			scannerPanels.add(sp);
			pnlMain.add(sp.getPanel(),gbc);
		}
		
		
		new JPanel();
		
		initializeCrtlPanel();
		initializeLogPanel();
//		initializeBaseTab();
//		initializeClassifierTab();
//		initializePhenotypeTab();
		frame.setVisible(true);
		
	}

	private void initializeCrtlPanel(){
		JPanel pnlControl=new JPanel(new GridBagLayout());
		
		GridBagConstraints gbc=new GridBagConstraints();
		gbc.weightx=0.0;
//		gbc.weighty=0.0;
		JLabel lblMonitor=new JLabel("Monitor");
		gbc.gridx=0;
		gbc.gridy=0;
		pnlControl.add(lblMonitor,gbc);
		
		ledMonitor=new LedLight(Color.green);
		ledMonitor.off();
		ledMonitor.setPreferredSize(new Dimension(13,13));
		gbc.gridx=0;
		gbc.gridy=1;
		pnlControl.add(ledMonitor,gbc);
		
		chkRow=new JCheckBox[2];
		gbc.weightx=0.3;
//		gbc.weighty=0.1;
		gbc.gridx=1;
		gbc.anchor=GridBagConstraints.EAST;
		for(int i=0;i<2;++i){
			gbc.gridy=i;
			chkRow[i]=new JCheckBox("Row "+(i+1));
			chkRow[i].setSelected(true);
			pnlControl.add(chkRow[i],gbc);
		}
		
		JLabel lblFolder=new JLabel("Folder:");
		gbc.weightx=0.3;
		gbc.gridx=2;
		gbc.gridy=0;
		gbc.anchor=GridBagConstraints.EAST;
		pnlControl.add(lblFolder,gbc);
		
		txtFolder=new JTextField(System.getProperty("user.home"));
		gbc.gridx=3;
		gbc.gridy=0;
		gbc.fill=GridBagConstraints.HORIZONTAL;
		gbc.anchor=GridBagConstraints.CENTER;
		pnlControl.add(txtFolder,gbc);
		
		btnFolderChoose=new JButton("...");
		btnFolderChoose.setPreferredSize(new Dimension(25,25));
		gbc.gridx=4;
		gbc.gridy=0;
		gbc.fill=GridBagConstraints.NONE;
		pnlControl.add(btnFolderChoose,gbc);
		
		JLabel lblPrefix=new JLabel("Prefix:");
		gbc.weightx=0.9;
//		gbc.weighty=0.9;
		gbc.gridx=2;
		gbc.gridy=1;
		gbc.fill=GridBagConstraints.NONE;
		gbc.anchor=GridBagConstraints.EAST;
		pnlControl.add(lblPrefix,gbc);
		
		txtPrefix=new JTextField("_set1_day1");
		gbc.gridx=3;
		gbc.gridy=1;
		gbc.fill=GridBagConstraints.HORIZONTAL;
		gbc.anchor=GridBagConstraints.CENTER;
		pnlControl.add(txtPrefix,gbc);
		
		btnReset=new JButton("Reset");
		btnReset.setPreferredSize(new Dimension(80,25));
		gbc.weightx=0.1;
//		gbc.weighty=0.1;
		gbc.gridx=5;
		gbc.gridy=0;
		gbc.fill=GridBagConstraints.NONE;
		pnlControl.add(btnReset,gbc);
		
		btnExit=new JButton("Exit");
		btnExit.setPreferredSize(new Dimension(80,25));
		gbc.gridx=5;
		gbc.gridy=1;
		pnlControl.add(btnExit,gbc);

		btnScan=new JButton("Scan");
		btnScan.setPreferredSize(new Dimension(80,50));
		gbc.gridx=6;
		gbc.gridy=0;
		gbc.gridheight=2;
		gbc.fill=GridBagConstraints.VERTICAL;
		pnlControl.add(btnScan,gbc);

		pnlControl.setBorder(new TitledBorder("Control"));
		frame.getContentPane().add(pnlControl);
	}
	
	private void initializeLogPanel(){
		JPanel logPnl = new JPanel();
		frame.getContentPane().add(logPnl);
		logPnl.setLayout(new BorderLayout(0, 0));

		logArea=new JTextArea();
		logArea.setEditable(false);
		logArea.setFont(new Font("Monospaced",Font.PLAIN,10));
		DefaultCaret caret = (DefaultCaret)logArea.getCaret();
		caret.setUpdatePolicy(DefaultCaret.ALWAYS_UPDATE);		//logArea.setPreferredSize(new Dimension(400,Short.MAX_VALUE));
		JScrollPane logPane=new JScrollPane(logArea);
		logPane.setVerticalScrollBarPolicy(JScrollPane.VERTICAL_SCROLLBAR_AS_NEEDED);
		logPane.setHorizontalScrollBarPolicy(JScrollPane.HORIZONTAL_SCROLLBAR_AS_NEEDED);
		logPane.setBorder(new TitledBorder("Log Area"));
		logPane.setPreferredSize(new Dimension(400,300)); //Short.MAX_VALUE));

		logPnl.add(logPane, BorderLayout.CENTER);

		JPanel pnlLogAction = new JPanel();
		logPnl.add(pnlLogAction, BorderLayout.SOUTH);

		JButton btnWriteLog = new JButton("Write Log");
		pnlLogAction.add(btnWriteLog);


	}
	
	public void updateScanners(){
//		scannersActive=0;
		for(int i=0;i<8;++i){
			if(scanners.get(i)==null){
				scannerPanels.get(i).setActive(false);
			}
			else{
				scannerPanels.get(i).setActive(true);
				scanners.get(i).addProcessingListener(new PropertyChangeHandler());
				scanners.get(i).addProgressListener(new PropertyChangeHandler());
//				if(scannerPanels.get(i).isActive()){
//					
//				}
			}
		}
	}
	
	
	private void dispatcher(){
		usbCfg=new UsbConfig(cfgPath);
		for(int i=0;i<2;++i){
			if(!usbCfg.rowEnabled(i)){
				chkRow[i].setSelected(false);
				chkRow[i].setEnabled(false);
			}
		}
		
		usbCfg.addMonitorListener(new PropertyChangeHandler());
		
		usbCfg.addConfigListener(new PropertyChangeHandler());
		
		btnExit.addActionListener(new ActionHandler());
		btnReset.addActionListener(new ActionHandler());
		btnScan.addActionListener(new ActionHandler());
		btnFolderChoose.addActionListener(new ActionHandler());
		
		usbCfg.start();

		txtPrefix.getDocument().addDocumentListener(new DocumentHandler());
//		new Thread(){
//			public void run(){
//		try {
//			Thread.sleep(3000);
//			usbCfg.interrupt();
//		} catch (InterruptedException e) {
//			// TODO Auto-generated catch block
//			e.printStackTrace();
//		}
//			}
//		}.start();
		
//		while(true){}
	}
	
	private void reset(){
		new Thread(){
			public void run(){
//				if(workers!=null){
//					for(int i=0;i<workers.size();++i){
//						workers.get(i).interrupt();
//					}
//				}
				if(scanThread!=null)
					scanThread.interrupt();
				usbCfg.interrupt();
				try {
					for(int i=0;i<8;++i){
						if(scanners.get(i)!=null){
							scanners.get(i).destroyProcess();
							Thread.sleep(200);
						}
						scannerPanels.get(i).ledOnlineOff();
						scannerPanels.get(i).ledBusyOff();
						Thread.sleep(100);
					}
					usbCfg.join(500);

					Thread.sleep(300);
					
					usbCfg=new UsbConfig(cfgPath);
					usbCfg.addMonitorListener(new PropertyChangeHandler());
					usbCfg.addConfigListener(new PropertyChangeHandler());
					usbCfg.start();
					nextPlateNr=1;
					updateFileFields();
//						if(scannerPanels.get(i).isActive()){
//							scannerPanels.get(i).setNextPlateNr(nextPlateNr);
//							scannerPanels.get(i).updateFileField(txtPrefix.getText());
//							nextPlateNr++;
//						}
////						scannerPanels.get(i).resetNextPlateNr();
////						scannerPanels.get(i).updateFileField(txtPrefix.getText());
//					}
//					for(int i=0;i<workers.size();++i){
//							workers.get(i).join(500);
//					}
					scanThread.join();
					for(int i=0;i<8;++i){
						scannerPanels.get(i).setProgress(0);
					}
				} catch (InterruptedException e1) {
					e1.printStackTrace();
				}
			}
		}.start();
	}
	
	public void scan(){
		boolean scannerAvail=false;
		for(int i=0;i<8;++i){
			if(scanners.get(i)!=null){
				scannerAvail=true;
				break;
			}
		}
		if(!scannerAvail){
			log.info("No scanners available!!");
			return;
		}
		scanThread=new Thread(){
			public void run(){
				List<ScanWorker> workers=null;
				try {
					if(chkRow[0].isSelected()){
						workers=new ArrayList<ScanWorker>();
						for(int i=0;i<8;++i){
							if(scanners.get(i)!=null && scannerPanels.get(i).isActive()){
								ScanWorker scanWorker=new ScanWorker(scanners.get(i),0,txtFolder.getText()+System.getProperty("file.separator")+scannerPanels.get(i).getFileName()+".tif");
								scanWorker.start();
								workers.add(scanWorker);
								Thread.sleep(500);
							}
						}
						for(int i=0;i<workers.size();++i){
							workers.get(i).join();
						}		
						Thread.sleep(3000);

						for(int i=0;i<8;++i){
							//						scannerPanels.get(i).setNextPlateNr(scannerPanels.get(i).getNextPlateNr()+scannersActive);//+scanners.size());
							//						scannerPanels.get(i).updateFileField(txtPrefix.getText());
							//scannerPanels.get(i).setProgress(0);
							if(scannerPanels.get(i).isActive()){
								nextPlateNr++;
							}
						}
						updateFileFields();
					}

					if(chkRow[1].isSelected() && !isInterrupted()){
						workers=new ArrayList<ScanWorker>();
						for(int i=0;i<8;++i){

							if(scanners.get(i)!=null && scannerPanels.get(i).isActive()){
								ScanWorker scanWorker=new ScanWorker(scanners.get(i),1,txtFolder.getText()+System.getProperty("file.separator")+scannerPanels.get(i).getFileName()+".tif");
								scanWorker.start();
								workers.add(scanWorker);
								Thread.sleep(500);
							}
						}
						for(int i=0;i<workers.size();++i){
							workers.get(i).join();
						}
						for(int i=0;i<8;++i){
							//						scannerPanels.get(i).setNextPlateNr(scannerPanels.get(i).getNextPlateNr()+scannersActive);//+scanners.size());
							//						scannerPanels.get(i).updateFileField(txtPrefix.getText());
							//scannerPanels.get(i).setProgress(0);
							if(scannerPanels.get(i).isActive()){
								nextPlateNr++;
							}
						}
						updateFileFields();
					}
				}
				catch(InterruptedException ie){
					if(workers!=null){
						for(ScanWorker w:workers){
							w.interrupt();
//							try {
//								w.join();
//							} catch (InterruptedException e) {
//								// TODO Auto-generated catch block
//								e.printStackTrace();
//							}
						}
					}
					//return;
				}
				finally{
					for(int i=0;i<8;++i){
						scannerPanels.get(i).setProgress(0);
					}
				}
			}

		};
		scanThread.start();
	}
	
	private void updateFileFields(){
		int activeCnt=-1;
		for(int i=0;i<8;++i){
			if(scannerPanels.get(i).isActive()){
				activeCnt++;
				scannerPanels.get(i).setNextPlateNr(nextPlateNr+activeCnt);//+scanners.size());
			}
			scannerPanels.get(i).updateFileField(txtPrefix.getText());
//			scannerPanels.get(i).setProgress(0);
		}
		
	}
	
	class ScanWorker extends Thread{
		Scanner scanner;
		int row;
		String filepath;
		
		public ScanWorker(Scanner scanner,int row,String filepath){
			this.scanner=scanner;
			this.row=row;
			this.filepath=filepath;
			
		}
		
		public void run(){
			int returnValue=999;
			int retryCnt=1;
			while(returnValue!=0 && retryCnt<=10 && !isInterrupted()){
				log.info("Scanner "+scanner.getLogical()+": starting to scan row "+row);
				returnValue=scanner.scanImage(row,filepath);
				log.info("Scanning failed on scanner"+scanner.getLogical()+"\n"+
						 "Will retry in 2 seconds ("+retryCnt+"/10)");
				retryCnt++;
				try {
					sleep(2000);
				} catch (InterruptedException e) {
					log.info("scan worker "+scanner.getLogical()+" was interrupted");
					return;
					//e.printStackTrace();
				}
				
			}
		}
	}
	
	class PropertyChangeHandler implements PropertyChangeListener{

		@Override
		public void propertyChange(PropertyChangeEvent evt) {
			if(evt.getPropertyName().equals("monitoringScanners")){
				if((Boolean)evt.getNewValue()){
					ledMonitor.on();
				}
				else{
					ledMonitor.off();
				}
			}
			else if(evt.getPropertyName().equals("ScannerConfigChanged")){
				scanners=(List<Scanner>)evt.getNewValue();
				updateScanners();
				updateFileFields();
			}
			else if(evt.getPropertyName().equals("ScanProcessing")){
				scannerPanels.get((Integer)evt.getNewValue()).ledBusyOn();
			}
			else if(evt.getPropertyName().equals("ScanFinished")){
				scannerPanels.get((Integer)evt.getNewValue()).ledBusyOff();
			}
			else if(evt.getPropertyName().equals("ProgressChanged")){
				int pnlNr=(Integer)evt.getOldValue();
				scannerPanels.get(pnlNr).setProgress((Double)evt.getNewValue());
			}
		}
	}
	
	class ActionHandler implements ActionListener{

		@Override
		public void actionPerformed(ActionEvent e) {
			if(e.getSource()==btnExit){
				usbCfg.interrupt();
				for(int i=0;i<8;++i){
					if(scanners.get(i)!=null){
						scanners.get(i).destroyProcess();
					}
				}
				frame.dispose();
				System.exit(0);
			}
			else if(e.getSource()==btnReset){
				reset();
			}
			else if(e.getSource()==btnScan){
				scan();
			}
			else if(e.getSource()==btnFolderChoose){
				JFileChooser fc=new JFileChooser();
				fc.setFileSelectionMode(JFileChooser.FILES_AND_DIRECTORIES);
				
				int state=fc.showOpenDialog(null);
				if(state==JFileChooser.APPROVE_OPTION){
					File file=fc.getSelectedFile();
					if(file.isDirectory()){
						txtFolder.setText(file.getAbsolutePath());
					}
					else{
						log.info("selected file is not a directory");
					}
				}
				
			}
		}
		
	}
	
	class DocumentHandler implements DocumentListener{

		@Override
		public void insertUpdate(DocumentEvent e) {
			updateImageFileNames();			
		}

		@Override
		public void removeUpdate(DocumentEvent e) {
			updateImageFileNames();
			
		}

		@Override
		public void changedUpdate(DocumentEvent e) {
			// TODO Auto-generated method stub
			
		}
		
		private void updateImageFileNames(){
			for(int i=0;i<8;++i){
				scannerPanels.get(i).updateFileField(txtPrefix.getText());
			}
		}
		
	}
	
	class CheckBoxHandler implements ItemListener{

		@Override
		public void itemStateChanged(ItemEvent e) {
			updateImageFileNames();
		}
		private void updateImageFileNames(){
//			int scannersActive=0;
//			for(int i=0;i<8;++i){
//				if(scannerPanels.get(i).isActive()){
//					scannersActive++;
//				}
//				nextPlateNr-=scannersActive;
				updateFileFields();
//				scannerPanels.get(i).updateFileField(txtPrefix.getText());
//			}
		}
		
	}
//	private void initializeBaseTab() {
//		JPanel pnlIdentifier = new JPanel();
//		//pnlIdentifier.setMinimumSize(new Dimension(400,0));
//		pnlIdentifier.setBorder(new TitledBorder("Identifiers"));
//		tabBaseDir.add(pnlIdentifier);
//
//		JLabel lblFileIdentifier = new JLabel("File Identifier:");
//		lblFileIdentifier.setLabelFor(txtFileIdentifier);
//		JLabel lblSetIdentifier = new JLabel("Set Identifier:");
//		JLabel lblPlateIdentifier = new JLabel("Plate Identifier:");
//		JLabel lblDayIdentifier = new JLabel("Day Identifier:");
//		JLabel lblPlantIdentifier = new JLabel("Plant Identifier:");
//
//		txtFileIdentifier = new JTextField();
//		txtFileIdentifier.setColumns(20);
//		txtSetIdentifier = new JTextField();
//		txtSetIdentifier.setColumns(20);
//		txtPlateIdentifier = new JTextField();
//		txtPlateIdentifier.setColumns(20);
//		txtDayIdentifier = new JTextField();
//		txtDayIdentifier.setColumns(20);
//		txtPlantIdentifier = new JTextField();
//		txtPlantIdentifier.setColumns(20);
//
//		GroupLayout gl_PnlIdentifier=new GroupLayout(pnlIdentifier);
//		gl_PnlIdentifier.setAutoCreateContainerGaps(true);
//		gl_PnlIdentifier.setAutoCreateGaps(true);
//		gl_PnlIdentifier.setLayoutStyle(null);
//		pnlIdentifier.setLayout(gl_PnlIdentifier);
//
//		//horizontal
//		GroupLayout.ParallelGroup columnLeft=gl_PnlIdentifier.createParallelGroup()
//				.addComponent(lblFileIdentifier,GroupLayout.DEFAULT_SIZE,GroupLayout.DEFAULT_SIZE,GroupLayout.PREFERRED_SIZE)
//				.addComponent(lblSetIdentifier,GroupLayout.DEFAULT_SIZE,GroupLayout.DEFAULT_SIZE,GroupLayout.PREFERRED_SIZE)
//				.addComponent(lblPlateIdentifier,GroupLayout.DEFAULT_SIZE,GroupLayout.DEFAULT_SIZE,GroupLayout.PREFERRED_SIZE)
//				.addComponent(lblDayIdentifier,GroupLayout.DEFAULT_SIZE,GroupLayout.DEFAULT_SIZE,GroupLayout.PREFERRED_SIZE)
//				.addComponent(lblPlantIdentifier,GroupLayout.DEFAULT_SIZE,GroupLayout.DEFAULT_SIZE,GroupLayout.PREFERRED_SIZE);
//		GroupLayout.ParallelGroup columnRight=gl_PnlIdentifier.createParallelGroup()
//				.addComponent(txtFileIdentifier,GroupLayout.DEFAULT_SIZE,GroupLayout.DEFAULT_SIZE,GroupLayout.PREFERRED_SIZE)
//				.addComponent(txtSetIdentifier,GroupLayout.DEFAULT_SIZE,GroupLayout.DEFAULT_SIZE,GroupLayout.PREFERRED_SIZE)
//				.addComponent(txtPlateIdentifier,GroupLayout.DEFAULT_SIZE,GroupLayout.DEFAULT_SIZE,GroupLayout.PREFERRED_SIZE)
//				.addComponent(txtDayIdentifier,GroupLayout.DEFAULT_SIZE,GroupLayout.DEFAULT_SIZE,GroupLayout.PREFERRED_SIZE)
//				.addComponent(txtPlantIdentifier,GroupLayout.DEFAULT_SIZE,GroupLayout.DEFAULT_SIZE,GroupLayout.PREFERRED_SIZE);
//		GroupLayout.SequentialGroup leftToRight=gl_PnlIdentifier.createSequentialGroup().addGroup(columnLeft).addGroup(columnRight);
//		gl_PnlIdentifier.setHorizontalGroup(leftToRight);
//
//		//vertical
//		GroupLayout.ParallelGroup row1=gl_PnlIdentifier.createParallelGroup(Alignment.CENTER)
//				.addComponent(lblFileIdentifier,GroupLayout.DEFAULT_SIZE,GroupLayout.DEFAULT_SIZE,GroupLayout.PREFERRED_SIZE)
//				.addComponent(txtFileIdentifier,GroupLayout.DEFAULT_SIZE,GroupLayout.DEFAULT_SIZE,GroupLayout.PREFERRED_SIZE);
//		GroupLayout.ParallelGroup row2=gl_PnlIdentifier.createParallelGroup(Alignment.CENTER)
//				.addComponent(lblSetIdentifier,GroupLayout.DEFAULT_SIZE,GroupLayout.DEFAULT_SIZE,GroupLayout.PREFERRED_SIZE)
//				.addComponent(txtSetIdentifier,GroupLayout.DEFAULT_SIZE,GroupLayout.DEFAULT_SIZE,GroupLayout.PREFERRED_SIZE);
//		GroupLayout.ParallelGroup row3=gl_PnlIdentifier.createParallelGroup(Alignment.CENTER)
//				.addComponent(lblPlateIdentifier,GroupLayout.DEFAULT_SIZE,GroupLayout.DEFAULT_SIZE,GroupLayout.PREFERRED_SIZE)
//				.addComponent(txtPlateIdentifier,GroupLayout.DEFAULT_SIZE,GroupLayout.DEFAULT_SIZE,GroupLayout.PREFERRED_SIZE);
//		GroupLayout.ParallelGroup row4=gl_PnlIdentifier.createParallelGroup(Alignment.CENTER)
//				.addComponent(lblDayIdentifier,GroupLayout.DEFAULT_SIZE,GroupLayout.DEFAULT_SIZE,GroupLayout.PREFERRED_SIZE)
//				.addComponent(txtDayIdentifier,GroupLayout.DEFAULT_SIZE,GroupLayout.DEFAULT_SIZE,GroupLayout.PREFERRED_SIZE);
//		GroupLayout.ParallelGroup row5=gl_PnlIdentifier.createParallelGroup(Alignment.CENTER)
//				.addComponent(lblPlantIdentifier,GroupLayout.DEFAULT_SIZE,GroupLayout.DEFAULT_SIZE,GroupLayout.PREFERRED_SIZE)
//				.addComponent(txtPlantIdentifier,GroupLayout.DEFAULT_SIZE,GroupLayout.DEFAULT_SIZE,GroupLayout.PREFERRED_SIZE);
//		GroupLayout.SequentialGroup topToBottom=gl_PnlIdentifier.createSequentialGroup()
//				.addGroup(row1)
//				.addGroup(row2)
//				.addGroup(row3)
//				.addGroup(row4)
//				.addGroup(row5);
//		gl_PnlIdentifier.setVerticalGroup(topToBottom);
//
//		// Base Dir Panel
//		JPanel pnlBaseDir=new JPanel();
//		pnlBaseDir.setMinimumSize(new Dimension(400,0));
//		pnlBaseDir.setBorder(new TitledBorder("Base Directory"));
//		GridBagLayout gridBagLayout = new GridBagLayout();
//		gridBagLayout.columnWidths = new int[]{50,0,100,70,30};
//		gridBagLayout.rowHeights = new int[]{19, 0};
//		gridBagLayout.columnWeights = new double[]{0.0, 0.0, 0.0, 0.0, Double.MIN_VALUE};
//		gridBagLayout.rowWeights = new double[]{0.0, Double.MIN_VALUE};
//		pnlBaseDir.setLayout(gridBagLayout);
//
//		txtBaseDir = new JTextField(20);
//		GridBagConstraints gbc_textField = new GridBagConstraints();
//		gbc_textField.fill = GridBagConstraints.BOTH;
//		gbc_textField.insets = new Insets(3, 3, 3, 3);
//		gbc_textField.gridx = 0;
//		gbc_textField.gridy = 0;
//		gbc_textField.gridwidth=4;
//		gbc_textField.weightx=1.0;
//		pnlBaseDir.add(txtBaseDir, gbc_textField);
//
//		GridBagConstraints gbc_btnBaseDirSelect = new GridBagConstraints();
//		gbc_btnBaseDirSelect.fill = GridBagConstraints.VERTICAL;
//		gbc_btnBaseDirSelect.insets = new Insets(0, 3, 3, 3);
//		gbc_btnBaseDirSelect.gridx = 4;
//		gbc_btnBaseDirSelect.gridy = 0;
//		gbc_btnBaseDirSelect.weightx=0;
//		gbc_btnBaseDirSelect.anchor=GridBagConstraints.EAST;
//		btnBaseDirSelect = new JButton("...");
//		pnlBaseDir.add(btnBaseDirSelect,gbc_btnBaseDirSelect);
//		btnBaseDirSelect.setPreferredSize(new Dimension(30, 25));
//		btnBaseDirSelect.setMaximumSize(new Dimension(30, 25));
//		btnBaseDirSelect.setMinimumSize(new Dimension(20, 20));
//
//		JPanel lblLabel = new JPanel(new FlowLayout());
//		ledBaseDirGreen = new LedLight(Color.green);
//		ledBaseDirRed = new LedLight(Color.red);
//		ledBaseDirGreen.setPreferredSize(new Dimension(13,13));
//		ledBaseDirRed.setPreferredSize(new Dimension(13,13));
//		ledBaseDirGreen.off();
//		ledBaseDirRed.on();
//		lblLabel.add(ledBaseDirGreen);
//		lblLabel.add(ledBaseDirRed);
//		GridBagConstraints gbc_lblLabel = new GridBagConstraints();
//		gbc_lblLabel.insets = new Insets(0, 3, 3, 3);
//		gbc_lblLabel.gridx = 0;
//		gbc_lblLabel.gridy = 1;
//		gbc_lblLabel.weightx=1.0;
//		gbc_lblLabel.anchor=GridBagConstraints.WEST;
//		gbc_lblLabel.fill=GridBagConstraints.VERTICAL;
//		pnlBaseDir.add(lblLabel, gbc_lblLabel);
//
//		btnBaseDirReset = new JButton("Reset");
//		GridBagConstraints gbc_btnBaseDirReset = new GridBagConstraints();
//		gbc_btnBaseDirReset.insets = new Insets(0, 0, 3, 3);
//		gbc_btnBaseDirReset.gridx = 2;
//		gbc_btnBaseDirReset.gridy = 1;
//		gbc_btnBaseDirReset.weightx=0;
//		gbc_btnBaseDirReset.fill=GridBagConstraints.BOTH;
//		pnlBaseDir.add(btnBaseDirReset, gbc_btnBaseDirReset);
//
//		btnBaseDirRead = new JButton("Read");
//		GridBagConstraints gbc_btnBaseDirRead = new GridBagConstraints();
//		gbc_btnBaseDirRead.insets = new Insets(0, 0, 3, 3);
//		gbc_btnBaseDirRead.gridx = 3;
//		gbc_btnBaseDirRead.gridy = 1;
//		gbc_btnBaseDirRead.gridwidth=2;
//		gbc_btnBaseDirRead.fill=GridBagConstraints.BOTH;
//		pnlBaseDir.add(btnBaseDirRead, gbc_btnBaseDirRead);
//
//		GroupLayout gl_TabBase=new GroupLayout(tabBaseDir);
//		tabBaseDir.setLayout(gl_TabBase);
//		gl_TabBase.setHorizontalGroup(
//				gl_TabBase.createSequentialGroup()
//				.addGap(0, 0, Short.MAX_VALUE)
//				.addGroup(
//						gl_TabBase.createParallelGroup(Alignment.CENTER)
//						.addComponent(pnlIdentifier,GroupLayout.DEFAULT_SIZE,GroupLayout.DEFAULT_SIZE,GroupLayout.DEFAULT_SIZE)
//						.addComponent(pnlBaseDir,GroupLayout.DEFAULT_SIZE,GroupLayout.DEFAULT_SIZE,GroupLayout.DEFAULT_SIZE)
//						)
//						.addGap(0, 0, Short.MAX_VALUE)
//				);
//		gl_TabBase.setVerticalGroup(
//				gl_TabBase.createSequentialGroup()
//				.addComponent(pnlIdentifier,GroupLayout.DEFAULT_SIZE,GroupLayout.DEFAULT_SIZE,GroupLayout.PREFERRED_SIZE)
//				.addComponent(pnlBaseDir,GroupLayout.DEFAULT_SIZE,GroupLayout.DEFAULT_SIZE,GroupLayout.PREFERRED_SIZE)
//				);
//
//		gl_TabBase.linkSize(SwingConstants.HORIZONTAL,pnlIdentifier,pnlBaseDir);
//
//		// set defaults
//		txtFileIdentifier.setText(options.getProperty("filesIdentifier","Object.*txt"));
//		txtSetIdentifier.setText(options.getProperty("setIdentifier","set\\d"));
//		txtPlateIdentifier.setText(options.getProperty("plateIdentifier","_\\d{3}$"));
//		txtDayIdentifier.setText(options.getProperty("dayIdentifier","day\\d"));
//		txtPlantIdentifier.setText(options.getProperty("plantIdentifier","Plant_\\d+"));
//		txtBaseDir.setText(options.getProperty("baseDir",System.getProperty("user.home")));
//
//		// handle actions
////		BaseTabListener tabListener=new BaseTabListener();
////		btnBaseDirRead.addActionListener(tabListener);
////		btnBaseDirReset.addActionListener(tabListener);
////		btnBaseDirSelect.addActionListener(tabListener);
//	}
//
//	private void initializeClassifierTab(){
//		JPanel pnlUserClass=new JPanel();
//		pnlUserClass.setMinimumSize(new Dimension(400,0));
//		pnlUserClass.setBorder(new TitledBorder("User Classification"));
//		GridBagLayout gridBagLayout = new GridBagLayout();
//		gridBagLayout.columnWidths = new int[]{50,0,100,70,30};
//		gridBagLayout.rowHeights = new int[]{19, 0};
//		gridBagLayout.columnWeights = new double[]{0.0, 0.0, 0.0, 0.0, Double.MIN_VALUE};
//		gridBagLayout.rowWeights = new double[]{0.0, Double.MIN_VALUE};
//		pnlUserClass.setLayout(gridBagLayout);
//
//		txtUserClass = new JTextField(20);
//		GridBagConstraints gbc_textField = new GridBagConstraints();
//		gbc_textField.fill = GridBagConstraints.BOTH;
//		gbc_textField.insets = new Insets(3, 3, 3, 3);
//		gbc_textField.gridx = 0;
//		gbc_textField.gridy = 0;
//		gbc_textField.gridwidth=4;
//		gbc_textField.weightx=1.0;
//		pnlUserClass.add(txtUserClass, gbc_textField);
//
//		GridBagConstraints gbc_btnUserClassSelect = new GridBagConstraints();
//		gbc_btnUserClassSelect.fill = GridBagConstraints.VERTICAL;
//		gbc_btnUserClassSelect.insets = new Insets(0, 3, 3, 3);
//		gbc_btnUserClassSelect.gridx = 4;
//		gbc_btnUserClassSelect.gridy = 0;
//		gbc_btnUserClassSelect.weightx=0;
//		gbc_btnUserClassSelect.anchor=GridBagConstraints.EAST;
//		btnUserClassSelect = new JButton("...");
//		pnlUserClass.add(btnUserClassSelect,gbc_btnUserClassSelect);
//		btnUserClassSelect.setPreferredSize(new Dimension(30, 25));
//		btnUserClassSelect.setMaximumSize(new Dimension(30, 25));
//		btnUserClassSelect.setMinimumSize(new Dimension(20, 20));
//
//		JPanel lblLabel = new JPanel(new FlowLayout());
//		ledUserClassGreen = new LedLight(Color.green);
//		ledUserClassRed = new LedLight(Color.red);
//		ledUserClassGreen.setPreferredSize(new Dimension(13,13));
//		ledUserClassRed.setPreferredSize(new Dimension(13,13));
//		ledUserClassGreen.off();
//		ledUserClassRed.on();
//		lblLabel.add(ledUserClassGreen);
//		lblLabel.add(ledUserClassRed);
//		GridBagConstraints gbc_lblLabel = new GridBagConstraints();
//		gbc_lblLabel.insets = new Insets(0, 3, 3, 3);
//		gbc_lblLabel.gridx = 0;
//		gbc_lblLabel.gridy = 1;
//		gbc_lblLabel.weightx=1.0;
//		gbc_lblLabel.anchor=GridBagConstraints.WEST;
//		gbc_lblLabel.fill=GridBagConstraints.VERTICAL;
//		pnlUserClass.add(lblLabel, gbc_lblLabel);
//
//		btnUserClassReset = new JButton("Reset");
//		GridBagConstraints gbc_btnUserClassReset = new GridBagConstraints();
//		gbc_btnUserClassReset.insets = new Insets(0, 0, 3, 3);
//		gbc_btnUserClassReset.gridx = 2;
//		gbc_btnUserClassReset.gridy = 1;
//		gbc_btnUserClassReset.weightx=0;
//		gbc_btnUserClassReset.fill=GridBagConstraints.BOTH;
//		pnlUserClass.add(btnUserClassReset, gbc_btnUserClassReset);
//
//		btnUserClassRead = new JButton("Read");
//		GridBagConstraints gbc_btnUserClassRead = new GridBagConstraints();
//		gbc_btnUserClassRead.insets = new Insets(0, 0, 3, 3);
//		gbc_btnUserClassRead.gridx = 3;
//		gbc_btnUserClassRead.gridy = 1;
//		gbc_btnUserClassRead.gridwidth=2;
//		gbc_btnUserClassRead.fill=GridBagConstraints.BOTH;
//		pnlUserClass.add(btnUserClassRead, gbc_btnUserClassRead);
//
//		tabClassifier.add(pnlUserClass);
//
//
//		JPanel pnlPlateLayout=new JPanel();
//		pnlPlateLayout.setBorder(new TitledBorder("Plate Layout"));
//		GridBagLayout gl_pnlPlateLayout = new GridBagLayout();
//		gl_pnlPlateLayout.columnWidths = new int[]{50,0,100,70,30};
//		gl_pnlPlateLayout.rowHeights = new int[]{19,0,0};
//		gl_pnlPlateLayout.columnWeights = new double[]{0.0, 0.0, 0.0, 0.0, Double.MIN_VALUE};
//		gl_pnlPlateLayout.rowWeights = new double[]{0.0,0.0,Double.MIN_VALUE};
//		pnlPlateLayout.setLayout(gl_pnlPlateLayout);
//
//		txtPlateLayout = new JTextField(20);
//		GridBagConstraints gbc_txtPlateLayout = new GridBagConstraints();
//		gbc_txtPlateLayout.fill = GridBagConstraints.BOTH;
//		gbc_txtPlateLayout.insets = new Insets(3, 3, 3, 3);
//		gbc_txtPlateLayout.gridx = 0;
//		gbc_txtPlateLayout.gridy = 1;
//		gbc_txtPlateLayout.gridwidth=4;
//		gbc_txtPlateLayout.weightx=1.0;
//		pnlPlateLayout.add(txtPlateLayout, gbc_txtPlateLayout);
//
//		GridBagConstraints gbc_btnPlateLayoutSelect = new GridBagConstraints();
//		gbc_btnPlateLayoutSelect.fill = GridBagConstraints.VERTICAL;
//		gbc_btnPlateLayoutSelect.insets = new Insets(0, 3, 3, 3);
//		gbc_btnPlateLayoutSelect.gridx = 4;
//		gbc_btnPlateLayoutSelect.gridy = 1;
//		gbc_btnPlateLayoutSelect.weightx=0;
//		gbc_btnPlateLayoutSelect.anchor=GridBagConstraints.EAST;
//		btnPlateLayoutSelect = new JButton("...");
//		pnlPlateLayout.add(btnPlateLayoutSelect,gbc_btnPlateLayoutSelect);
//		btnPlateLayoutSelect.setPreferredSize(new Dimension(30, 25));
//		btnPlateLayoutSelect.setMaximumSize(new Dimension(30, 25));
//		btnPlateLayoutSelect.setMinimumSize(new Dimension(20, 20));
//
//
//		JPanel pnlLayoutSub=new JPanel();
//		pnlLayoutSub.setLayout(new GridBagLayout());
//		GridBagConstraints gbc_pnlLayoutSub = new GridBagConstraints();
//		gbc_pnlLayoutSub.fill = GridBagConstraints.HORIZONTAL;
//		//gbc_.insets = new Insets(0, 3, 3, 3);
//		gbc_pnlLayoutSub.gridx = 0;
//		gbc_pnlLayoutSub.gridy = 0;
//		gbc_pnlLayoutSub.gridwidth=5;
//		gbc_pnlLayoutSub.weightx=1;
//		gbc_pnlLayoutSub.anchor=GridBagConstraints.EAST;
//		pnlPlateLayout.add(pnlLayoutSub,gbc_pnlLayoutSub);
//
//		JLabel lblLayoutCols=new JLabel("Columns: ");
//		GridBagConstraints gbc_lblLayoutCols = new GridBagConstraints();
//		//gbc_lblLayoutCols.fill = GridBagConstraints.HORIZONTAL;
//		//gbc_.insets = new Insets(0, 3, 3, 3);
//		gbc_lblLayoutCols.gridx = 0;
//		gbc_lblLayoutCols.gridy = 0;
//		gbc_lblLayoutCols.weightx=1;
//		gbc_lblLayoutCols.anchor=GridBagConstraints.EAST;
//		pnlLayoutSub.add(lblLayoutCols,gbc_lblLayoutCols);
//
//		txtLayoutCols=new JTextField(3);
//		txtLayoutCols.setPreferredSize(new Dimension(20,21));
//		txtLayoutCols.setText(options.getProperty("layout.cols","12"));
//		GridBagConstraints gbc_txtLayoutCols = new GridBagConstraints();
//		//gbc_txtLayoutCols.fill = GridBagConstraints.HORIZONTAL;
//		//gbc_.insets = new Insets(0, 3, 3, 3);
//		gbc_txtLayoutCols.gridx = 1;
//		gbc_txtLayoutCols.gridy = 0;
//		gbc_txtLayoutCols.weightx=1;
//		gbc_txtLayoutCols.anchor=GridBagConstraints.WEST;
//		pnlLayoutSub.add(txtLayoutCols,gbc_txtLayoutCols);
//
//		JLabel lblLayoutRows=new JLabel("Rows: ");
//		GridBagConstraints gbc_lblLayoutRows = new GridBagConstraints();
//		//gbc_lblLayoutRows.fill = GridBagConstraints.HORIZONTAL;
//		//gbc_.insets = new Insets(0, 3, 3, 3);
//		gbc_lblLayoutRows.gridx = 0;
//		gbc_lblLayoutRows.gridy = 1;
//		gbc_lblLayoutRows.weightx=1;
//		gbc_lblLayoutRows.anchor=GridBagConstraints.EAST;
//		pnlLayoutSub.add(lblLayoutRows,gbc_lblLayoutRows);
//
//		txtLayoutRows=new JTextField(3);
//		txtLayoutRows.setPreferredSize(new Dimension(20,21));
//		txtLayoutRows.setText(options.getProperty("layout.rows","2"));
//		GridBagConstraints gbc_txtLayoutRows = new GridBagConstraints();
//		//gbc_txtLayoutRows.fill = GridBagConstraints.HORIZONTAL;
//		//gbc_.insets = new Insets(0, 3, 3, 3);
//		gbc_txtLayoutRows.gridx = 1;
//		gbc_txtLayoutRows.gridy = 1;
//		gbc_txtLayoutRows.weightx=1;
//		gbc_txtLayoutRows.anchor=GridBagConstraints.WEST;
//		pnlLayoutSub.add(txtLayoutRows,gbc_txtLayoutRows);
//
//
//		JPanel lblPlateLayout = new JPanel(new FlowLayout());
//		lblPlateLayout.setToolTipText("current plate layout is not valid");
//		ledPlateLayoutGreen = new LedLight(Color.green);
//		ledPlateLayoutRed = new LedLight(Color.red);
//		ledPlateLayoutYellow=new LedLight(Color.orange);
//		ledPlateLayoutGreen.setPreferredSize(new Dimension(13,13));
//		ledPlateLayoutRed.setPreferredSize(new Dimension(13,13));
//		ledPlateLayoutYellow.setPreferredSize(new Dimension(13,13));
//		ledPlateLayoutGreen.off();
//		ledPlateLayoutRed.on();
//		ledPlateLayoutYellow.off();
//		lblPlateLayout.add(ledPlateLayoutGreen);
//		lblPlateLayout.add(ledPlateLayoutYellow);
//		lblPlateLayout.add(ledPlateLayoutRed);
//		GridBagConstraints gbc_lblPlateLayout = new GridBagConstraints();
//		gbc_lblPlateLayout.insets = new Insets(10, 3, 0, 3);
//		gbc_lblPlateLayout.gridx = 0;
//		gbc_lblPlateLayout.gridy = 5;
//		gbc_lblPlateLayout.weightx=1.0;
//		gbc_lblPlateLayout.anchor=GridBagConstraints.WEST;
//		gbc_lblPlateLayout.fill=GridBagConstraints.VERTICAL;
//		pnlPlateLayout.add(lblPlateLayout, gbc_lblPlateLayout);
//
//
//		btnPlateLayoutToFile = new JButton("To File");
//		GridBagConstraints gbc_btnPlateLayoutToFile = new GridBagConstraints();
//		gbc_btnPlateLayoutToFile.insets = new Insets(0, 3, 3, 3);
//		gbc_btnPlateLayoutToFile.gridx = 2;
//		gbc_btnPlateLayoutToFile.gridy = 2;
//		gbc_btnPlateLayoutToFile.weightx=0;
//		gbc_btnPlateLayoutToFile.fill=GridBagConstraints.BOTH;
//		pnlPlateLayout.add(btnPlateLayoutToFile, gbc_btnPlateLayoutToFile);
//
//		btnPlateLayoutFromFile = new JButton("From File");
//		GridBagConstraints gbc_btnPlateLayoutFromFile = new GridBagConstraints();
//		gbc_btnPlateLayoutFromFile.insets = new Insets(0, 0, 3, 3);
//		gbc_btnPlateLayoutFromFile.gridx = 3;
//		gbc_btnPlateLayoutFromFile.gridy = 2;
//		gbc_btnPlateLayoutFromFile.gridwidth=2;
//		gbc_btnPlateLayoutFromFile.fill=GridBagConstraints.BOTH;
//		pnlPlateLayout.add(btnPlateLayoutFromFile, gbc_btnPlateLayoutFromFile);
//
//		btnPlateLayoutAuto = new JButton("Auto");
//		GridBagConstraints gbc_btnPlateLayoutReset = new GridBagConstraints();
//		gbc_btnPlateLayoutReset.insets = new Insets(0, 3, 3, 3);
//		gbc_btnPlateLayoutReset.gridx = 2;
//		gbc_btnPlateLayoutReset.gridy = 3;
//		gbc_btnPlateLayoutReset.weightx=0;
//		gbc_btnPlateLayoutReset.fill=GridBagConstraints.BOTH;
//		pnlPlateLayout.add(btnPlateLayoutAuto, gbc_btnPlateLayoutReset);
//
//		btnPlateLayoutManual = new JButton("Manual");
//		GridBagConstraints gbc_btnPlateLayoutRead = new GridBagConstraints();
//		gbc_btnPlateLayoutRead.insets = new Insets(0, 0, 3, 3);
//		gbc_btnPlateLayoutRead.gridx = 3;
//		gbc_btnPlateLayoutRead.gridy = 3;
//		gbc_btnPlateLayoutRead.gridwidth=2;
//		gbc_btnPlateLayoutRead.fill=GridBagConstraints.BOTH;
//		pnlPlateLayout.add(btnPlateLayoutManual, gbc_btnPlateLayoutRead);
//
//		//			JSeparator sepPlateLayout=new JSeparator(JSeparator.HORIZONTAL);
//		//			GridBagConstraints gbc_sepPlateLayout = new GridBagConstraints();
//		//			gbc_sepPlateLayout.insets = new Insets(0, 0, 3, 0);
//		//			gbc_sepPlateLayout.gridx = 2;
//		//			gbc_sepPlateLayout.gridy = 3;
//		//			gbc_sepPlateLayout.gridwidth=3;
//		//			gbc_sepPlateLayout.fill=GridBagConstraints.BOTH;
//		//			pnlPlateLayout.add(sepPlateLayout, gbc_sepPlateLayout);
//
//		btnPlateLayoutAssign = new JButton("Assign");
//		GridBagConstraints gbc_btnPlateLayoutAssign = new GridBagConstraints();
//		gbc_btnPlateLayoutAssign.insets = new Insets(10, 3, 3, 3);
//		gbc_btnPlateLayoutAssign.gridx = 2;
//		gbc_btnPlateLayoutAssign.gridy = 5;
//		gbc_btnPlateLayoutAssign.fill=GridBagConstraints.BOTH;
//		pnlPlateLayout.add(btnPlateLayoutAssign, gbc_btnPlateLayoutAssign);
//
//		btnPlateLayoutStats = new JButton("Stats");
//		GridBagConstraints gbc_btnPlateLayoutStats = new GridBagConstraints();
//		gbc_btnPlateLayoutStats.insets = new Insets(10, 0, 3, 3);
//		gbc_btnPlateLayoutStats.gridx = 3;
//		gbc_btnPlateLayoutStats.gridy = 5;
//		gbc_btnPlateLayoutStats.gridwidth=2;
//		gbc_btnPlateLayoutStats.fill=GridBagConstraints.BOTH;
//		pnlPlateLayout.add(btnPlateLayoutStats, gbc_btnPlateLayoutStats);
//
//		tabClassifier.add(pnlPlateLayout);
//
//		JPanel pnlWekaClass=new JPanel();
//		pnlWekaClass.setBorder(new TitledBorder("Weka Model"));
//		GridBagLayout gl_pnlWekaClass = new GridBagLayout();
//		gl_pnlWekaClass.columnWidths = new int[]{50,0,100,70,30};
//		gl_pnlWekaClass.rowHeights = new int[]{19,0,0,0};
//		gl_pnlWekaClass.columnWeights = new double[]{0.0, 0.0, 0.0, 0.0, Double.MIN_VALUE};
//		gl_pnlWekaClass.rowWeights = new double[]{0.0,0.0,0.0,Double.MIN_VALUE};
//		pnlWekaClass.setLayout(gl_pnlWekaClass);
//
//		txtWekaClass = new JTextField(20);
//		GridBagConstraints gbc_txtWekaClass = new GridBagConstraints();
//		gbc_txtWekaClass.fill = GridBagConstraints.BOTH;
//		gbc_txtWekaClass.insets = new Insets(3, 3, 3, 3);
//		gbc_txtWekaClass.gridx = 0;
//		gbc_txtWekaClass.gridy = 0;
//		gbc_txtWekaClass.gridwidth=4;
//		gbc_txtWekaClass.weightx=1.0;
//		pnlWekaClass.add(txtWekaClass, gbc_txtWekaClass);
//
//		GridBagConstraints gbc_btnWekaClassSelect = new GridBagConstraints();
//		gbc_btnWekaClassSelect.fill = GridBagConstraints.VERTICAL;
//		gbc_btnWekaClassSelect.insets = new Insets(0, 3, 3, 3);
//		gbc_btnWekaClassSelect.gridx = 4;
//		gbc_btnWekaClassSelect.gridy = 0;
//		gbc_btnWekaClassSelect.weightx=0;
//		gbc_btnWekaClassSelect.anchor=GridBagConstraints.EAST;
//		btnWekaClassSelect = new JButton("...");
//		pnlWekaClass.add(btnWekaClassSelect,gbc_btnWekaClassSelect);
//		btnWekaClassSelect.setPreferredSize(new Dimension(30, 25));
//		btnWekaClassSelect.setMaximumSize(new Dimension(30, 25));
//		btnWekaClassSelect.setMinimumSize(new Dimension(20, 20));
//
//		JPanel lblWekaClass = new JPanel(new FlowLayout());
//		ledWekaClassGreen = new LedLight(Color.green);
//		ledWekaClassRed = new LedLight(Color.red);
//		ledWekaClassYellow = new LedLight(Color.orange);
//		ledWekaClassGreen.setPreferredSize(new Dimension(13,13));
//		ledWekaClassRed.setPreferredSize(new Dimension(13,13));
//		ledWekaClassYellow.setPreferredSize(new Dimension(13,13));
//		ledWekaClassGreen.off();
//		ledWekaClassYellow.off();
//		ledWekaClassRed.on();
//		lblWekaClass.add(ledWekaClassGreen);
//		lblWekaClass.add(ledWekaClassYellow);
//		lblWekaClass.add(ledWekaClassRed);
//		GridBagConstraints gbc_lblWekaClass = new GridBagConstraints();
//		gbc_lblWekaClass.insets = new Insets(10, 3, 0, 3);
//		gbc_lblWekaClass.gridx = 0;
//		gbc_lblWekaClass.gridy = 4;
//		gbc_lblWekaClass.weightx=1.0;
//		gbc_lblWekaClass.anchor=GridBagConstraints.WEST;
//		gbc_lblWekaClass.fill=GridBagConstraints.VERTICAL;
//		pnlWekaClass.add(lblWekaClass, gbc_lblWekaClass);
//
//		btnWekaClassToFile = new JButton("To File");
//		GridBagConstraints gbc_btnWekaClassReset = new GridBagConstraints();
//		gbc_btnWekaClassReset.insets = new Insets(0, 3, 3, 3);
//		gbc_btnWekaClassReset.gridx = 2;
//		gbc_btnWekaClassReset.gridy = 1;
//		gbc_btnWekaClassReset.weightx=0;
//		gbc_btnWekaClassReset.fill=GridBagConstraints.BOTH;
//		pnlWekaClass.add(btnWekaClassToFile, gbc_btnWekaClassReset);
//
//		btnWekaClassFromFile = new JButton("From File");
//		GridBagConstraints gbc_btnWekaClassRead = new GridBagConstraints();
//		gbc_btnWekaClassRead.insets = new Insets(0, 0, 3, 3);
//		gbc_btnWekaClassRead.gridx = 3;
//		gbc_btnWekaClassRead.gridy = 1;
//		gbc_btnWekaClassRead.gridwidth=2;
//		gbc_btnWekaClassRead.fill=GridBagConstraints.BOTH;
//		pnlWekaClass.add(btnWekaClassFromFile, gbc_btnWekaClassRead);
//
//		btnWekaClassCross = new JButton("C-Cor");
//		GridBagConstraints gbc_btnWekaClassCross = new GridBagConstraints();
//		gbc_btnWekaClassCross.insets = new Insets(0, 3, 3, 3);
//		gbc_btnWekaClassCross.gridx = 2;
//		gbc_btnWekaClassCross.gridy = 2;
//		gbc_btnWekaClassCross.weightx=0;
//		gbc_btnWekaClassCross.fill=GridBagConstraints.BOTH;
//		pnlWekaClass.add(btnWekaClassCross, gbc_btnWekaClassCross);
//
//		btnWekaClassCreate= new JButton("Create");
//		GridBagConstraints gbc_btnWekaClassCreate = new GridBagConstraints();
//		gbc_btnWekaClassCreate.insets = new Insets(0, 0, 3, 3);
//		gbc_btnWekaClassCreate.gridx = 3;
//		gbc_btnWekaClassCreate.gridy = 2;
//		gbc_btnWekaClassCreate.gridwidth=2;
//		gbc_btnWekaClassCreate.fill=GridBagConstraints.BOTH;
//		pnlWekaClass.add(btnWekaClassCreate, gbc_btnWekaClassCreate);
//
//		//			JSeparator sepWekaClass=new JSeparator(JSeparator.HORIZONTAL);
//		//			GridBagConstraints gbc_WekaClassSep = new GridBagConstraints();
//		//			gbc_WekaClassSep.insets = new Insets(0, 0, 3, 0);
//		//			gbc_WekaClassSep.gridx = 0;
//		//			gbc_WekaClassSep.gridy = 3;
//		//			gbc_WekaClassSep.gridwidth=3;
//		//			gbc_WekaClassSep.fill=GridBagConstraints.BOTH;
//		//			pnlWekaClass.add(sepWekaClass, gbc_WekaClassSep);
//
//		btnWekaClassClassify = new JButton("Classify");
//		GridBagConstraints gbc_btnWekaClassClassify = new GridBagConstraints();
//		gbc_btnWekaClassClassify.insets = new Insets(10, 3, 3, 3);
//		gbc_btnWekaClassClassify.gridx = 2;
//		gbc_btnWekaClassClassify.gridy = 4;
//		gbc_btnWekaClassClassify.weightx=0;
//		gbc_btnWekaClassClassify.fill=GridBagConstraints.BOTH;
//		pnlWekaClass.add(btnWekaClassClassify, gbc_btnWekaClassClassify);
//
//		btnWekaClassStats= new JButton("Stats");
//		GridBagConstraints gbc_btnWekaClassStats = new GridBagConstraints();
//		gbc_btnWekaClassStats.insets = new Insets(10, 0, 3, 3);
//		gbc_btnWekaClassStats.gridx = 3;
//		gbc_btnWekaClassStats.gridy = 4;
//		gbc_btnWekaClassStats.gridwidth=2;
//		gbc_btnWekaClassStats.fill=GridBagConstraints.BOTH;
//		pnlWekaClass.add(btnWekaClassStats, gbc_btnWekaClassStats);
//
//		tabClassifier.add(pnlWekaClass);
//
//
//		JPanel pnlComStats=new JPanel(new FlowLayout(FlowLayout.TRAILING));
//		pnlComStats.setBorder(new TitledBorder("Combined Statistics"));
//		//			GridBagLayout gl_pnlComStats = new GridBagLayout();
//		//			gl_pnlComStats.columnWidths = new int[]{50,100,100,70,30};
//		//			gl_pnlComStats.rowHeights = new int[]{0,0};
//		//			gl_pnlComStats.columnWeights = new double[]{0.0, 0.0, 0.0, 0.0, Double.MIN_VALUE};
//		//			gl_pnlComStats.rowWeights = new double[]{0.0,Double.MIN_VALUE};
//		//			pnlComStats.setLayout(gl_pnlComStats);
//		//			
//		//			GridBagConstraints gbc_btnComStatsSelect = new GridBagConstraints();
//		//			gbc_btnComStatsSelect.fill = GridBagConstraints.BOTH;
//		//			gbc_btnComStatsSelect.insets = new Insets(3, 3, 3, 3);
//		//			gbc_btnComStatsSelect.gridx = 2;
//		//			gbc_btnComStatsSelect.gridy = 0;
//		//			gbc_btnComStatsSelect.weightx=0;
//		//			gbc_btnComStatsSelect.anchor=GridBagConstraints.EAST;
//		btnComStatsSelect = new JButton("Stats");
//		btnComStatsSelect.setPreferredSize(new Dimension(100,25));
//		//			pnlComStats.add(btnComStatsSelect,gbc_btnComStatsSelect);
//		pnlComStats.add(btnComStatsSelect);
//		tabClassifier.add(pnlComStats);
//
//		//			tabClassifier.setLayout(new BoxLayout(tabClassifier,BoxLayout.Y_AXIS));
//		GroupLayout gl_TabClassifier=new GroupLayout(tabClassifier);
//		tabClassifier.setLayout(gl_TabClassifier);
//		gl_TabClassifier.setHorizontalGroup(
//				gl_TabClassifier.createSequentialGroup()
//				.addGroup(
//						gl_TabClassifier.createParallelGroup(Alignment.CENTER)
//						.addComponent(pnlUserClass,GroupLayout.DEFAULT_SIZE,GroupLayout.PREFERRED_SIZE,GroupLayout.DEFAULT_SIZE)
//						.addComponent(pnlWekaClass,GroupLayout.DEFAULT_SIZE,GroupLayout.PREFERRED_SIZE,GroupLayout.DEFAULT_SIZE)
//						.addComponent(pnlPlateLayout,GroupLayout.DEFAULT_SIZE,GroupLayout.PREFERRED_SIZE,GroupLayout.DEFAULT_SIZE)
//						.addComponent(pnlComStats,GroupLayout.DEFAULT_SIZE,GroupLayout.PREFERRED_SIZE,GroupLayout.DEFAULT_SIZE)
//						)
//				);
//		gl_TabClassifier.setVerticalGroup(
//				gl_TabClassifier.createSequentialGroup()
//				.addComponent(pnlUserClass,GroupLayout.DEFAULT_SIZE,GroupLayout.DEFAULT_SIZE,GroupLayout.PREFERRED_SIZE)
//				.addComponent(pnlWekaClass,GroupLayout.DEFAULT_SIZE,GroupLayout.DEFAULT_SIZE,GroupLayout.PREFERRED_SIZE)
//				.addComponent(pnlPlateLayout,GroupLayout.DEFAULT_SIZE,GroupLayout.DEFAULT_SIZE,GroupLayout.PREFERRED_SIZE)
//				.addComponent(pnlComStats,GroupLayout.DEFAULT_SIZE,GroupLayout.DEFAULT_SIZE,GroupLayout.PREFERRED_SIZE)
//				);
//
//		//gl_TabClassifier.linkSize(SwingConstants.HORIZONTAL,pnlIdentifier,pnlBaseDir);
//
//
//		//set defaults
//		txtUserClass.setText(options.getProperty("userClassFile",txtBaseDir.getText()));
//		txtWekaClass.setText(options.getProperty("wekaModelFile",txtBaseDir.getText()));
//		txtPlateLayout.setText(options.getProperty("plateLayoutFile",txtBaseDir.getText()));
//		//handle actions
////		ClassifierTabListener tablistener=new ClassifierTabListener();
////		btnUserClassRead.addActionListener(tablistener);
////		btnUserClassReset.addActionListener(tablistener);
////		btnUserClassSelect.addActionListener(tablistener);
////
////		btnPlateLayoutFromFile.addActionListener(tablistener);
////		btnPlateLayoutToFile.addActionListener(tablistener);
////		btnPlateLayoutSelect.addActionListener(tablistener);
////		btnPlateLayoutAuto.addActionListener(tablistener);
////		btnPlateLayoutManual.addActionListener(tablistener);
////		btnPlateLayoutStats.addActionListener(tablistener);
////		btnPlateLayoutAssign.addActionListener(tablistener);
////
////		btnWekaClassClassify.addActionListener(tablistener);
////		btnWekaClassCreate.addActionListener(tablistener);
////		btnWekaClassCross.addActionListener(tablistener);
////		btnWekaClassFromFile.addActionListener(tablistener);
////		btnWekaClassToFile.addActionListener(tablistener);
////		btnWekaClassSelect.addActionListener(tablistener);
////		btnWekaClassStats.addActionListener(tablistener);
////
////		btnComStatsSelect.addActionListener(tablistener);
//	}
//
//	private void initializePhenotypeTab(){
//		JPanel pnlAccFile=new JPanel();
//		pnlAccFile.setMinimumSize(new Dimension(400,0));
//		pnlAccFile.setBorder(new TitledBorder("Accession Layout"));
//		GridBagLayout gridBagLayout = new GridBagLayout();
//		gridBagLayout.columnWidths = new int[]{50,0,100,70,30};
//		gridBagLayout.rowHeights = new int[]{19, 0};
//		gridBagLayout.columnWeights = new double[]{0.0, 0.0, 0.0, 0.0, Double.MIN_VALUE};
//		gridBagLayout.rowWeights = new double[]{0.0, Double.MIN_VALUE};
//		pnlAccFile.setLayout(gridBagLayout);
//
//		txtAccFile = new JTextField(20);
//		GridBagConstraints gbc_textField = new GridBagConstraints();
//		gbc_textField.fill = GridBagConstraints.BOTH;
//		gbc_textField.insets = new Insets(3, 3, 3, 3);
//		gbc_textField.gridx = 0;
//		gbc_textField.gridy = 0;
//		gbc_textField.gridwidth=4;
//		gbc_textField.weightx=1.0;
//		pnlAccFile.add(txtAccFile, gbc_textField);
//
//		GridBagConstraints gbc_btnAccFileSelect = new GridBagConstraints();
//		gbc_btnAccFileSelect.fill = GridBagConstraints.VERTICAL;
//		gbc_btnAccFileSelect.insets = new Insets(0, 3, 3, 3);
//		gbc_btnAccFileSelect.gridx = 4;
//		gbc_btnAccFileSelect.gridy = 0;
//		gbc_btnAccFileSelect.weightx=0;
//		gbc_btnAccFileSelect.anchor=GridBagConstraints.EAST;
//		btnAccFileSelect = new JButton("...");
//		pnlAccFile.add(btnAccFileSelect,gbc_btnAccFileSelect);
//		btnAccFileSelect.setPreferredSize(new Dimension(30, 25));
//		btnAccFileSelect.setMaximumSize(new Dimension(30, 25));
//		btnAccFileSelect.setMinimumSize(new Dimension(20, 20));
//
//		JPanel lblLabel = new JPanel(new FlowLayout());
//		ledAccFileGreen = new LedLight(Color.green);
//		ledAccFileRed = new LedLight(Color.red);
//		ledAccFileGreen.setPreferredSize(new Dimension(13,13));
//		ledAccFileRed.setPreferredSize(new Dimension(13,13));
//		ledAccFileGreen.off();
//		ledAccFileRed.on();
//		lblLabel.add(ledAccFileGreen);
//		lblLabel.add(ledAccFileRed);
//		GridBagConstraints gbc_lblLabel = new GridBagConstraints();
//		gbc_lblLabel.insets = new Insets(0, 3, 3, 3);
//		gbc_lblLabel.gridx = 0;
//		gbc_lblLabel.gridy = 1;
//		gbc_lblLabel.weightx=1.0;
//		gbc_lblLabel.anchor=GridBagConstraints.WEST;
//		gbc_lblLabel.fill=GridBagConstraints.VERTICAL;
//		pnlAccFile.add(lblLabel, gbc_lblLabel);
//
//		btnAccFileReset = new JButton("Reset");
//		GridBagConstraints gbc_btnAccFileReset = new GridBagConstraints();
//		gbc_btnAccFileReset.insets = new Insets(0, 0, 3, 3);
//		gbc_btnAccFileReset.gridx = 2;
//		gbc_btnAccFileReset.gridy = 1;
//		gbc_btnAccFileReset.weightx=0;
//		gbc_btnAccFileReset.fill=GridBagConstraints.BOTH;
//		pnlAccFile.add(btnAccFileReset, gbc_btnAccFileReset);
//
//		btnAccFileRead = new JButton("Read");
//		GridBagConstraints gbc_btnAccFileRead = new GridBagConstraints();
//		gbc_btnAccFileRead.insets = new Insets(0, 0, 3, 3);
//		gbc_btnAccFileRead.gridx = 3;
//		gbc_btnAccFileRead.gridy = 1;
//		gbc_btnAccFileRead.gridwidth=2;
//		gbc_btnAccFileRead.fill=GridBagConstraints.BOTH;
//		pnlAccFile.add(btnAccFileRead, gbc_btnAccFileRead);
//
//		tabPhenotype.add(pnlAccFile);
//
//
//
//		JPanel pnlOutputPath=new JPanel();
//		pnlOutputPath.setMinimumSize(new Dimension(400,0));
//		pnlOutputPath.setBorder(new TitledBorder("Output Directory"));
//		GridBagLayout gbl_OutputPath = new GridBagLayout();
//		gbl_OutputPath.columnWidths = new int[]{50,100,0,70,30};
//		gbl_OutputPath.rowHeights = new int[]{19,0,0};
//		gbl_OutputPath.columnWeights = new double[]{0.0, 0.0, 0.0, 0.0, Double.MIN_VALUE};
//		gbl_OutputPath.rowWeights = new double[]{0.0,0.0,Double.MIN_VALUE};
//		pnlOutputPath.setLayout(gbl_OutputPath);
//
//		txtOutputPath = new JTextField(20);
//		GridBagConstraints gbc_txtOutputPath = new GridBagConstraints();
//		gbc_txtOutputPath.fill = GridBagConstraints.BOTH;
//		gbc_txtOutputPath.insets = new Insets(3, 3, 3, 3);
//		gbc_txtOutputPath.gridx = 0;
//		gbc_txtOutputPath.gridy = 0;
//		gbc_txtOutputPath.gridwidth=4;
//		gbc_txtOutputPath.weightx=1.0;
//		pnlOutputPath.add(txtOutputPath, gbc_txtOutputPath);
//
//		GridBagConstraints gbc_btnOutputPathSelect = new GridBagConstraints();
//		gbc_btnOutputPathSelect.fill = GridBagConstraints.VERTICAL;
//		gbc_btnOutputPathSelect.insets = new Insets(3, 0, 3, 3);
//		gbc_btnOutputPathSelect.gridx = 4;
//		gbc_btnOutputPathSelect.gridy = 0;
//		gbc_btnOutputPathSelect.weightx=0;
//		gbc_btnOutputPathSelect.anchor=GridBagConstraints.EAST;
//		btnOutputPathSelect = new JButton("...");
//		pnlOutputPath.add(btnOutputPathSelect,gbc_btnOutputPathSelect);
//		btnOutputPathSelect.setPreferredSize(new Dimension(30, 25));
//		btnOutputPathSelect.setMaximumSize(new Dimension(30, 25));
//		btnOutputPathSelect.setMinimumSize(new Dimension(20, 20));
//
//		//			JLabel lblOutputPrefix = new JLabel("<- Prefix");
//		//			GridBagConstraints gbc_lblOutputPrefix = new GridBagConstraints();
//		//			gbc_lblOutputPrefix.insets = new Insets(3, 3, 3, 3);
//		//			gbc_lblOutputPrefix.gridx = 3;
//		//			gbc_lblOutputPrefix.gridy = 1;
//		//			gbc_lblOutputPrefix.weightx=0;
//		//			gbc_lblOutputPrefix.gridwidth=2;
//		//			//gbc_lblOutputPrefix.anchor=GridBagConstraints.WEST;
//		//			//gbc_lblOutputPrefix.fill=GridBagConstraints.VERTICAL;
//		//			pnlOutputPath.add(lblOutputPrefix, gbc_lblOutputPrefix);
//
//		JButton lblPrefix=new JButton("<- Prefix");
//		lblPrefix.setEnabled(false);
//		GridBagConstraints gbc_lblPrefix = new GridBagConstraints();
//		gbc_lblPrefix.insets = new Insets(0, 0, 3, 3);
//		gbc_lblPrefix.gridx = 3;
//		gbc_lblPrefix.gridy = 1;
//		//gbc_lblPrefix.weightx=0;
//		gbc_lblPrefix.gridwidth=2;
//		//gbc_lblPrefix.anchor=GridBagConstraints.WEST;
//		gbc_lblPrefix.fill=GridBagConstraints.BOTH;
//		pnlOutputPath.add(lblPrefix, gbc_lblPrefix);
//
//
//		txtOutputPrefix = new JTextField(10);
//		GridBagConstraints gbc_txtPrefix = new GridBagConstraints();
//		gbc_txtPrefix.fill = GridBagConstraints.BOTH;
//		gbc_txtPrefix.insets = new Insets(0, 3, 3, 3);
//		gbc_txtPrefix.gridx = 0;
//		gbc_txtPrefix.gridy = 1;
//		gbc_txtPrefix.gridwidth=3;
//		gbc_txtPrefix.weightx=1.0;
//		pnlOutputPath.add(txtOutputPrefix, gbc_txtPrefix);
//
//		btnOutputWrite = new JButton("Write");
//		GridBagConstraints gbc_btnOutputPathReset = new GridBagConstraints();
//		gbc_btnOutputPathReset.insets = new Insets(0, 0, 3, 3);
//		gbc_btnOutputPathReset.gridx = 3;
//		gbc_btnOutputPathReset.gridy = 2;
//		gbc_btnOutputPathReset.weightx=0;
//		gbc_btnOutputPathReset.gridwidth=2;
//		gbc_btnOutputPathReset.fill=GridBagConstraints.BOTH;
//		pnlOutputPath.add(btnOutputWrite, gbc_btnOutputPathReset);
//
//
//		tabPhenotype.add(pnlOutputPath);
//
//
//
//		GroupLayout gl_TabPhenotype=new GroupLayout(tabPhenotype);
//		tabPhenotype.setLayout(gl_TabPhenotype);
//		gl_TabPhenotype.setHorizontalGroup(
//				gl_TabPhenotype.createSequentialGroup()
//				.addGroup(
//						gl_TabPhenotype.createParallelGroup(Alignment.CENTER)
//						.addComponent(pnlAccFile,GroupLayout.DEFAULT_SIZE,GroupLayout.PREFERRED_SIZE,GroupLayout.DEFAULT_SIZE)
//						.addComponent(pnlOutputPath,GroupLayout.DEFAULT_SIZE,GroupLayout.PREFERRED_SIZE,GroupLayout.DEFAULT_SIZE)
//						)
//				);
//		gl_TabPhenotype.setVerticalGroup(
//				gl_TabPhenotype.createSequentialGroup()
//				.addComponent(pnlAccFile,GroupLayout.DEFAULT_SIZE,GroupLayout.DEFAULT_SIZE,GroupLayout.PREFERRED_SIZE)
//				.addComponent(pnlOutputPath,GroupLayout.DEFAULT_SIZE,GroupLayout.DEFAULT_SIZE,GroupLayout.PREFERRED_SIZE)
//				);
//
//		// set defaults
//		txtAccFile.setText(options.getProperty("accLayoutFile",txtBaseDir.getText()));
//		txtOutputPath.setText(options.getProperty("outputDirectory",txtBaseDir.getText()));
//
//		//action handling
////		PhenotypeTabListener tabListener=new PhenotypeTabListener();
////		btnAccFileRead.addActionListener(tabListener);
////		btnAccFileReset.addActionListener(tabListener);
////		btnAccFileSelect.addActionListener(tabListener);
////
////		btnOutputPathSelect.addActionListener(tabListener);
////		btnOutputWrite.addActionListener(tabListener);
//
//
//	}
//
//
//	class BaseTabListener implements ActionListener{
//		SwingWorker<Void,Void> worker;
//		final String propStr=new String();
//		@Override
//		public void actionPerformed(ActionEvent e) {
//			if(e.getSource()==btnBaseDirRead){
//				worker=new SwingWorker<Void,Void>(){
//					protected Void doInBackground(){
//						try {
//							ledBaseDirRed.blink(300);
//							frame.setCursor(Cursor.getPredefinedCursor(Cursor.WAIT_CURSOR));
//
//							String baseDir=txtBaseDir.getText();
//							if(!baseDir.endsWith(System.getProperty("file.separator"))){
//								baseDir+=System.getProperty("file.separator");
//							}
//							String dayIdentifier=txtDayIdentifier.getText();
//							String plantIdentifier=txtPlantIdentifier.getText();
//							String filesIdentifier=txtFileIdentifier.getText();
//							String[] setIds={txtSetIdentifier.getText(),txtPlateIdentifier.getText()};
//							options.setProperty("baseDir",baseDir);
//							options.setProperty("dayIdentifier",dayIdentifier);
//							options.setProperty("plantIdentifier",plantIdentifier);
//							options.setProperty("filesIdentifier",filesIdentifier);
//							options.setProperty("setIdentifier",setIds[0]);
//							options.setProperty("plateIdentifier",setIds[1]);
//
//							exp=new Experiment(options,24);
//							exp.readBaseDir();
//
//							ledBaseDirRed.off();
//							ledBaseDirGreen.on();
//						} catch(InterruptedException e){
//							log.info("Reading interrupted!");
//							ledBaseDirRed.on();
//						} catch(Exception ex){
//							log.severe("error reading base directory!");
//							exp=null;
//							ledBaseDirRed.on();
//						} finally {
//							frame.setCursor(Cursor.getDefaultCursor());
//							saveOptions();
//						}
//						return null;
//					}
//				};
//				worker.execute(); 
//			}
//			else if(e.getSource()==btnBaseDirReset){
//				if(worker!=null){
//					worker.cancel(true);
//				}
//				log.info("Experiment resetted!");
//				exp=null;
//				ledBaseDirRed.on();
//				ledBaseDirGreen.off();
//				ledUserClassRed.on();
//				ledUserClassGreen.off();
//			}
//			else if(e.getSource()==btnBaseDirSelect){
//				JFileChooser chooser = new JFileChooser();
//				chooser.setCurrentDirectory(new File(txtBaseDir.getText()));
//				chooser.setDialogTitle("Choose the base directory");
//				chooser.setFileSelectionMode(JFileChooser.FILES_AND_DIRECTORIES);
//				chooser.setAcceptAllFileFilterUsed(false);
//
//				if(chooser.showOpenDialog(null) == JFileChooser.APPROVE_OPTION){
//					File selectedFile=chooser.getSelectedFile();
//					if(selectedFile.isDirectory())
//						txtBaseDir.setText(selectedFile.getAbsolutePath());
//					else
//						txtBaseDir.setText(selectedFile.getParent());
//				}
//
//			}
//		}
//	}
//
//	class ClassifierTabListener implements ActionListener{
//		SwingWorker<Void,Void> worker;
//
//		@Override
//		public void actionPerformed(ActionEvent e){
//			if(e.getSource()==btnUserClassRead){
//				if(ledBaseDirGreen.isOn){
//					worker=new SwingWorker<Void,Void>(){
//						protected Void doInBackground(){
//							try {
//								frame.setCursor(Cursor.getPredefinedCursor(Cursor.WAIT_CURSOR));
//								ledUserClassRed.blink(300);
//								String userQCFile=txtUserClass.getText();
//								options.setProperty("userClassFile",userQCFile);
//
//								exp.readUserQC(userQCFile);
//
//								ledUserClassRed.off();
//								ledUserClassGreen.on();
//							} catch(InterruptedException ex){
//								log.warning("Reading user classification interrupted!");
//								ledUserClassRed.on();
//							} catch(Exception ex){
//								ledUserClassRed.on();
//								log.warning("error reading user classification!"+newline+ex.getStackTrace().toString());
//								ex.printStackTrace();
//							} finally {
//								frame.setCursor(Cursor.getDefaultCursor());
//								saveOptions();
//							}
//							return null;
//						}
//					};
//					worker.execute();
//				}
//				else{
//					log.info("load base directory first!");
//				}
//			}
//			else if(e.getSource()==btnUserClassReset){
//				if(worker.isDone())
//					log.info("User classification resetted!");
//				else
//					worker.cancel(true);
//				if(exp!=null)
//					exp.resetUserQC();
//
//				ledUserClassRed.on();
//				ledUserClassGreen.off();
//			}
//			else if(e.getSource()==btnUserClassSelect){
//				JFileChooser chooser = new JFileChooser();
//				chooser.setCurrentDirectory(new File(txtUserClass.getText()));
//				chooser.setDialogTitle("User Classification File");
//				chooser.setFileSelectionMode(JFileChooser.FILES_AND_DIRECTORIES);
//				chooser.setAcceptAllFileFilterUsed(false);
//
//				if(chooser.showOpenDialog(null) == JFileChooser.APPROVE_OPTION)
//				{
//					txtUserClass.setText(chooser.getSelectedFile().getPath());
//				}
//			}
//			else if(e.getSource()==btnPlateLayoutFromFile){
//				if(ledBaseDirGreen.isOn){
//					worker=new SwingWorker<Void,Void>(){
//						protected Void doInBackground() throws Exception{
//							try{
//								frame.setCursor(Cursor.getPredefinedCursor(Cursor.WAIT_CURSOR));
//								ledPlateLayoutGreen.off();
//								ledPlateLayoutYellow.off();
//								ledPlateLayoutRed.blink(300);
//
//								String plateLayoutFile=txtPlateLayout.getText();
//								options.setProperty("plateLayoutFile",plateLayoutFile);
//
//								spatialLayout=new SpatialLayout(Integer.parseInt(txtLayoutCols.getText()),Integer.parseInt(txtLayoutRows.getText()));
//								spatialLayout.read(plateLayoutFile);
//
//								ledPlateLayoutRed.off();
//								ledPlateLayoutYellow.on();
//							}
//							catch(IOException ex){
//								ledPlateLayoutRed.on();
//								log.warning("error reading plate layout file!"+newline+ex.getStackTrace().toString());
//								ex.printStackTrace();
//							}
//							finally {
//								frame.setCursor(Cursor.getDefaultCursor());
//								saveOptions();
//							}
//							return null;
//						}
//					};
//					worker.execute();
//				}
//				else{
//					log.info("load base directory first!");
//				}
//			}
//			else if(e.getSource()==btnPlateLayoutAuto){
//				if(ledUserClassGreen.isOn){
//					worker=new SwingWorker<Void,Void>(){
//						protected Void doInBackground() throws Exception{
//							try{
//								frame.setCursor(Cursor.getPredefinedCursor(Cursor.WAIT_CURSOR));
//								ledPlateLayoutGreen.off();
//								ledPlateLayoutYellow.off();
//								ledPlateLayoutRed.blink(300);
//
//								exp.calcGridMedianPoints(Integer.parseInt(txtLayoutCols.getText()),Integer.parseInt(txtLayoutRows.getText()));
//								spatialLayout=new SpatialLayout(Integer.parseInt(txtLayoutCols.getText()),Integer.parseInt(txtLayoutRows.getText()));
//								spatialLayout=exp.getSpatialLayout();
//
//								ledPlateLayoutRed.off();
//								ledPlateLayoutYellow.on();
//							}
//							catch(Exception e){
//								log.warning("error creating plate layout!"+System.getProperty("line.separator")+e.getStackTrace());
//							}
//							finally{
//								frame.setCursor(Cursor.getDefaultCursor());
//							}
//							return null;
//						}
//					};
//					worker.execute();
//				}
//				else{
//					log.info("need user classification to create a spatial layout automatically.");
//				}
//			}
//			else if(e.getSource()==btnPlateLayoutToFile){
//				if(ledPlateLayoutYellow.isOn){
//					JFileChooser chooser = new JFileChooser();
//					chooser.setCurrentDirectory(new File(txtPlateLayout.getText()));//"/home/GMI/christian.goeschl/prj3/images/test/."));
//					chooser.setSelectedFile(new File(""));
//					chooser.setDialogTitle("Save plate layout to file");
//					chooser.setApproveButtonText("Save");
//					chooser.setFileSelectionMode(JFileChooser.FILES_AND_DIRECTORIES);
//					chooser.setFileFilter(new FileFilter(){
//						public boolean accept(File f){
//							if(f.isDirectory()) return true;
//							return (f.getName().toLowerCase().endsWith(".grid"));
//						}
//						public String getDescription(){
//							return "grid";
//						}
//					});
//					chooser.setAcceptAllFileFilterUsed(true);
//
//
//					if(chooser.showSaveDialog(null) == JFileChooser.APPROVE_OPTION)
//					{
//						String filepath=chooser.getSelectedFile().getAbsolutePath();
//						if(!filepath.endsWith(".grid")){
//							filepath+=".grid";
//						}
//						try {
//							exp.writeGridPoints(filepath);
//						} catch (IOException e1) {
//							log.severe("error writing plate layout file '"+filepath+"'!");
//							// TODO Auto-generated catch block
//							e1.printStackTrace();
//						}
//					}
//				}
//				else{
//					log.warning("current plate layout not valid. Can not write to file!");
//				}
//			}
//
//			else if(e.getSource()==btnPlateLayoutSelect){
//				JFileChooser chooser = new JFileChooser();
//				chooser.setCurrentDirectory(new File(txtPlateLayout.getText()));//"/home/GMI/christian.goeschl/prj3/images/test/."));
//				chooser.setDialogTitle("Select Platelayout File");
//				chooser.setFileSelectionMode(JFileChooser.FILES_AND_DIRECTORIES);
//				chooser.setFileFilter(new FileFilter(){
//					public boolean accept(File f){
//						if(f.isDirectory()) return true;
//						return (f.getName().toLowerCase().endsWith(".grid"));
//					}
//					public String getDescription(){
//						return "grid";
//					}
//				});
//				chooser.setAcceptAllFileFilterUsed(true);
//
//				if(chooser.showDialog(null,"Select") == JFileChooser.APPROVE_OPTION)
//				{
//					txtPlateLayout.setText(chooser.getSelectedFile().getPath());//getCurrentDirectory().getPath());
//				}
//
//			}
//			else if(e.getSource()==btnPlateLayoutManual){
//				frame.setCursor(Cursor.getPredefinedCursor(Cursor.WAIT_CURSOR));
//				ledPlateLayoutGreen.off();
//				ledPlateLayoutYellow.off();
//				ledPlateLayoutRed.blink(300);
//				manualLayout=new ManualLayout(options.getProperty("baseDir",System.getProperty("user.home")),24);
//				manualLayout.addDataOkListener(new LayoutChangeListener());
//				SwingUtilities.invokeLater(manualLayout);
//
//			}
//			else if(e.getSource()==btnPlateLayoutAssign){
//				if(ledPlateLayoutYellow.isOn()){
//					SwingWorker<Void,Void> worker=new SwingWorker<Void,Void>(){
//						protected Void doInBackground(){
//							try {
//								frame.setCursor(Cursor.getPredefinedCursor(Cursor.WAIT_CURSOR));
//								ledPlateLayoutGreen.blink(300);
//
//								log.info("assigning plant numbers");
//								spatialLayout.calcMaxDeviations();
//								exp.setSpatialLayout(spatialLayout);
//								exp.assignPlantNrByGrid();
//								exp.checkPlantSeriesNumbers();
//
//								ledPlateLayoutGreen.on();
//							} catch(Exception ex){
//								log.warning("error assigning plant numbers!");
//								ledPlateLayoutGreen.off();
//								ex.printStackTrace();
//								System.out.println("error assigning plant numbers!");
//							} finally {
//								frame.setCursor(Cursor.getDefaultCursor());
//							}
//							return null;
//						}
//					};
//					worker.execute();
//				}
//				else{
//					log.info("need a valid plate layout to do this step.");
//				}
//			}
//			else if(e.getSource()==btnPlateLayoutStats){
//				if(ledPlateLayoutGreen.isOn()){
//					try {
//						frame.setCursor(Cursor.getPredefinedCursor(Cursor.WAIT_CURSOR));
//
//						log.info(exp.getGridQCStats());
//
//					} catch(Exception ex){
//						log.warning("error getting grid QC statistics!");
//						ex.printStackTrace();
//					} finally {
//						frame.setCursor(Cursor.getDefaultCursor());
//					}
//				}
//				else{
//					log.info("assign plant numbers before");
//				}
//			}
//			else if(e.getSource()==btnWekaClassFromFile){
//				worker=new SwingWorker<Void,Void>(){
//					protected Void doInBackground(){
//						try{
//							frame.setCursor(Cursor.getPredefinedCursor(Cursor.WAIT_CURSOR));
//							ledWekaClassRed.blink(300);
//							String modelFile=txtWekaClass.getText();
//							options.setProperty("wekaModelFile",modelFile);
//
//							svm=new SVM();
//							svm.readModel(modelFile);
//
//							ledWekaClassRed.off();
//							ledWekaClassYellow.on();
//						}
//						catch(Exception ex){
//							ledWekaClassRed.on();
//							log.warning("error reading weka model!");
//							ex.printStackTrace();
//						}
//						finally {
//							frame.setCursor(Cursor.getDefaultCursor());
//							saveOptions();
//						}
//						return null;
//					}
//				};
//				worker.execute();
//			}
//			else if(e.getSource()==btnWekaClassToFile){
//				if(ledWekaClassYellow.isOn()){
//					JFileChooser chooser = new JFileChooser();
//					chooser.setCurrentDirectory(new File(txtWekaClass.getText()));//"/home/GMI/christian.goeschl/prj3/images/test/."));
//					chooser.setDialogTitle("Save Weka Model");
//					chooser.setFileFilter(new FileFilter(){
//						public boolean accept(File f){
//							if(f.isDirectory()) return true;
//							return (f.getName().toLowerCase().endsWith(".model"));
//						}
//						public String getDescription(){
//							return "model";
//						}
//					});
//					chooser.setAcceptAllFileFilterUsed(true);
//					if(chooser.showSaveDialog(null) == JFileChooser.APPROVE_OPTION)
//					{
//						String modelpath=chooser.getSelectedFile().getPath();
//						if(!modelpath.endsWith(".model")){
//							modelpath+=".model";
//						}
//						try {
//							svm.saveModel(modelpath);
//						}
//						catch (Exception e1) {
//							log.warning("Error writing model to file!");
//							e1.printStackTrace();
//						}
//
//
//					}
//				}
//				else{
//					log.info("current weka model not valid!");
//				}
//
//			}
//			else if(e.getSource()==btnWekaClassCreate){
//				if(ledBaseDirGreen.isOn()){
//					if(ledUserClassGreen.isOn()){
//						if(ledPlateLayoutYellow.isOn()){
//							worker=new SwingWorker<Void,Void>(){
//								protected Void doInBackground(){
//									try{
//										frame.setCursor(Cursor.getPredefinedCursor(Cursor.WAIT_CURSOR));
//										ledWekaClassGreen.off();
//										ledWekaClassYellow.off();
//										ledWekaClassRed.blink(300);
//										String tSetPath=System.getProperty("user.home")+System.getProperty("file.separator")+".tmpautoqctrain";
//										String uSetPath=System.getProperty("user.home")+System.getProperty("file.separator")+".tmpautoqcunlabeled";
//
//										svm=new SVM();
//										exp.writeTrainingSet(tSetPath);
//										exp.writeUnlabeledSet(uSetPath);
//										svm.readTrainingSet(tSetPath);
//										svm.readTestSet(uSetPath);
//										svm.setClassifierBayesNet();
//										svm.buildClassifier();
//										//new File(tSetPath).delete();
//
//										ledWekaClassRed.off();
//										ledWekaClassYellow.on();
//									}
//									catch(IOException e2){
//										ledWekaClassRed.on();
//										log.warning("IOException generating classifier model!");
//										e2.printStackTrace();
//									}
//									catch(Exception e){
//										log.warning("error creating weka model!"+System.getProperty("line.separator")+e.getMessage());
//									}
//									finally{
//										frame.setCursor(Cursor.getDefaultCursor());
//									}
//									return null;
//								}
//							};
//							worker.execute();
//						}
//
//						else{
//							log.info("create plate layout first!");
//						}
//					}
//					else{
//						log.info("read user classification first!");
//					}
//				}
//				else{
//					log.info("read base directory first");
//				}
//			}
//			else if(e.getSource()==btnWekaClassSelect){
//				JFileChooser chooser = new JFileChooser();
//				chooser.setCurrentDirectory(new File(txtWekaClass.getText()));//"/home/GMI/christian.goeschl/prj3/images/test/."));
//				chooser.setDialogTitle("Select Model File");
//				chooser.setFileSelectionMode(JFileChooser.FILES_AND_DIRECTORIES);
//				chooser.setFileFilter(new FileFilter(){
//					public boolean accept(File f){
//						if(f.isDirectory()) return true;
//						return (f.getName().toLowerCase().endsWith(".model"));
//					}
//					public String getDescription(){
//						return "model";
//					}
//				});
//				chooser.setAcceptAllFileFilterUsed(true);
//
//				if(chooser.showDialog(null,"Select") == JFileChooser.APPROVE_OPTION)
//				{
//					txtWekaClass.setText(chooser.getSelectedFile().getAbsolutePath());//getCurrentDirectory().getPath());
//				}
//			}
//			else if(e.getSource()==btnWekaClassCross){
//				if(ledWekaClassYellow.isOn()){
//					worker=new SwingWorker<Void,Void>(){
//						protected Void doInBackground(){
//							svm.crossValidation();
//							return null;
//						}
//					};
//					worker.execute();
//				}
//				else{
//					log.info("current weka model not valid!");
//				}
//			}
//			else if(e.getSource()==btnWekaClassClassify){
//				if(ledBaseDirGreen.isOn()){
//					if(ledWekaClassYellow.isOn()){
//						worker=new SwingWorker<Void,Void>(){
//							protected Void doInBackground(){
//								try {
//									frame.setCursor(Cursor.getPredefinedCursor(Cursor.WAIT_CURSOR));
//									ledWekaClassGreen.blink(300);
//
//									svm.classifySet();
//									exp.assignWekaClassifications(svm.getSetClassifications());
//
//									ledWekaClassGreen.on();
//								} catch(Exception ex){
//									ledWekaClassGreen.off();
//									log.warning("error classifying set!");
//									ex.printStackTrace();
//								} finally {
//									frame.setCursor(Cursor.getDefaultCursor());
//								}
//								return null;
//							}
//						};
//						worker.execute();
//					}
//					else{
//						log.info("current weka model not valid!");
//					}
//				}
//				else{
//					log.info("read base directory first");
//				}
//			}
//			else if(e.getSource()==btnWekaClassStats){
//				if(ledWekaClassGreen.isOn()){
//					worker=new SwingWorker<Void,Void>(){
//						protected Void doInBackground(){
//							try {
//								frame.setCursor(Cursor.getPredefinedCursor(Cursor.WAIT_CURSOR));
//
//								log.info(exp.getWekaQCStats());
//
//							} catch(Exception ex){
//								log.warning("error getting weka QC statistics!");
//								log.log(Level.FINER,"",ex);
//								ex.printStackTrace();
//							} finally {
//								frame.setCursor(Cursor.getDefaultCursor());
//							}
//							return null;
//						}
//					};
//					worker.execute();
//				}
//				else{
//					log.info("weka classification not done!");
//				}
//			}
//			else if(e.getSource()==btnComStatsSelect){
//				if(ledPlateLayoutGreen.isOn()){
//					if(ledWekaClassGreen.isOn()){
//						worker=new SwingWorker<Void,Void>(){
//							protected Void doInBackground(){
//								try {
//									frame.setCursor(Cursor.getPredefinedCursor(Cursor.WAIT_CURSOR));
//
//									log.info(exp.getCombinedStats());
//
//								} catch(Exception ex){
//									log.warning("error getting combined QC statistics!");
//									ex.printStackTrace();
//								} finally {
//									frame.setCursor(Cursor.getDefaultCursor());
//								}
//								return null;
//							}
//						};
//						worker.execute();
//					}
//					else{
//						log.info("weka classification not done!");
//					}
//				}
//				else{
//					log.info("plate layout assignment not done!");
//				}
//			}
//			//				else if(e.getSource()==arffLabeledBt){
//			//					JFileChooser chooser = new JFileChooser();
//			//					chooser.setCurrentDirectory(new File(userQCField.getText()));//"/home/GMI/christian.goeschl/prj3/images/test/."));
//			//					chooser.setSelectedFile(new File(""));
//			//					chooser.setDialogTitle("Save user classified arff file");
//			//					chooser.setApproveButtonText("Save");
//			//					chooser.setFileSelectionMode(JFileChooser.FILES_AND_DIRECTORIES);
//			//					chooser.setFileFilter(new FileFilter(){
//			//						public boolean accept(File f){
//			//							if(f.isDirectory()) return true;
//			//							return (f.getName().toLowerCase().endsWith(".arff"));
//			//						}
//			//						public String getDescription(){
//			//							return "arff";
//			//						}
//			//						
//			//					});
//			//					chooser.setAcceptAllFileFilterUsed(true);
//			//					
//			//					if(chooser.showOpenDialog(null) == JFileChooser.APPROVE_OPTION)
//			//					{
//			//						String filepath=chooser.getSelectedFile().getAbsolutePath();
//			//						if(!filepath.endsWith(".arff")){
//			//							filepath+=".arff";
//			//						}
//			//						try {
//			//							exp.writeTrainingSet(filepath);
//			//						} catch (IOException e1) {
//			//							System.out.println("IOException writing labeled set!");
//			//							e1.printStackTrace();
//			//						}
//			//					}
//			//				}
//			//				else if(e.getSource()==arffUnLabeledBt){
//			//					JFileChooser chooser = new JFileChooser();
//			//					chooser.setCurrentDirectory(new File(userQCField.getText()));//"/home/GMI/christian.goeschl/prj3/images/test/."));
//			//					chooser.setSelectedFile(new File(""));
//			//					chooser.setDialogTitle("Save not classified arff file");
//			//					chooser.setApproveButtonText("Save");
//			//					chooser.setFileSelectionMode(JFileChooser.FILES_AND_DIRECTORIES);
//			//					chooser.setFileFilter(new FileFilter(){
//			//						public boolean accept(File f){
//			//							if(f.isDirectory()) return true;
//			//							return (f.getName().toLowerCase().endsWith(".arff"));
//			//						}
//			//						public String getDescription(){
//			//							return "arff";
//			//						}
//			//						
//			//					});
//			//					chooser.setAcceptAllFileFilterUsed(true);
//			//					if(chooser.showOpenDialog(null) == JFileChooser.APPROVE_OPTION)
//			//					{
//			//						String filepath=chooser.getSelectedFile().getAbsolutePath();
//			//						if(!filepath.endsWith(".arff")){
//			//							filepath+=".arff";
//			//						}
//			//						try {
//			//							exp.writeUnlabeledSet(filepath);
//			//						} catch (IOException e1) {
//			//							System.out.println("IOException writing unlabeled set!");
//			//							e1.printStackTrace();
//			//						}
//			//					}
//			//				}
//		}
//	}
//
//	class PhenotypeTabListener implements ActionListener{
//		SwingWorker<Void,Void> worker;
//
//		@Override
//		public void actionPerformed(ActionEvent e) {
//			if(e.getSource()==btnAccFileSelect){
//				JFileChooser chooser = new JFileChooser();
//				chooser.setCurrentDirectory(new File(txtAccFile.getText()));//"/home/GMI/christian.goeschl/prj3/images/test/."));
//				chooser.setDialogTitle("Select accession layout file");
//				chooser.setFileSelectionMode(JFileChooser.FILES_AND_DIRECTORIES);
//				chooser.setFileFilter(new FileFilter(){
//					public boolean accept(File f){
//						if(f.isDirectory()) return true;
//						return (f.getName().toLowerCase().endsWith(".txt"));
//					}
//					public String getDescription(){
//						return "txt";
//					}
//				});
//				chooser.setAcceptAllFileFilterUsed(true);
//
//				if(chooser.showDialog(null,"Select") == JFileChooser.APPROVE_OPTION)
//				{
//					txtAccFile.setText(chooser.getSelectedFile().getPath());//getCurrentDirectory().getPath());
//				}
//			}
//			else if(e.getSource()==btnAccFileRead){
//				if(ledBaseDirGreen.isOn){
//					if(ledPlateLayoutGreen.isOn || ledUserClassGreen.isOn()){
//						worker=new SwingWorker<Void,Void>(){
//							protected Void doInBackground() throws Exception{
//								try{
//									frame.setCursor(Cursor.getPredefinedCursor(Cursor.WAIT_CURSOR));
//									ledAccFileGreen.off();
//									ledAccFileRed.blink(300);
//
//									String accLayoutFile=txtAccFile.getText();
//									options.setProperty("accLayoutFile",accLayoutFile);
//
//									if(exp.getSpatialLayout()==null){
//										exp.setSpatialLayout(new SpatialLayout(Integer.parseInt(txtLayoutCols.getText()),Integer.parseInt(txtLayoutRows.getText())));
//									}
//									exp.assignAccessions(accLayoutFile);
//
//									ledAccFileRed.off();
//									ledAccFileGreen.on();
//								}
//								catch(IOException ex){
//									ledAccFileRed.on();
//									log.warning("error reading accession layout file!"+newline+ex.getStackTrace().toString());
//									ex.printStackTrace();
//								}
//								finally {
//									frame.setCursor(Cursor.getDefaultCursor());
//									saveOptions();
//								}
//								return null;
//							}
//						};
//						worker.execute();
//					}
//					else{
//						log.info("plant numbers not assigned!");
//					}
//				}
//				else{
//					log.info("load base directory first!");
//				}
//
//			}
//			else if(e.getSource()==btnOutputWrite){
//				if(ledPlateLayoutGreen.isOn() || ledWekaClassGreen.isOn() || ledUserClassGreen.isOn()){
//					worker=new SwingWorker<Void,Void>(){
//						protected Void doInBackground() throws Exception{
//							try {
//								frame.setCursor(Cursor.getPredefinedCursor(Cursor.WAIT_CURSOR));
//
//								String path=txtOutputPath.getText();
//								File testpath=new File(path);
//								if(!testpath.exists()){
//									log.warning("Output path does not exist!");
//									return null;
//								}
//								if(!testpath.isDirectory()){
//									log.warning("Output path is not a directory!");
//									return null;
//								}
//
//								if(!path.endsWith(System.getProperty("file.separator"))){
//									path+=System.getProperty("file.separator");
//								}
//								options.setProperty("outputDirectory",path);
//								String prefix=txtOutputPrefix.getText();
//								if(prefix==null){
//									prefix="";
//								}
//								exp.writeRootQuants(path+prefix+"_quant_single_root_images_Brat.txt");
//								exp.calcPhenoTypeData();
//								exp.writeRootPhenotypes(path+prefix+"_single_root_phenotypes_Brat.txt");
//								exp.writeAccessionPhenoTypes(path+prefix+"_acc_phenotypes_Brat.txt");
//								log.info("wrote output files to '"+path+"'");
//
//							} catch(Exception ex){
//								log.log(Level.WARNING,"error writing output",ex);
//								ex.printStackTrace();
//							} finally {
//								frame.setCursor(Cursor.getDefaultCursor());
//								saveOptions();
//							}
//							return null;
//						}
//					};
//					worker.execute();
//				}
//				else{
//					log.warning("neither plate layout nor weka classification assigned!");
//				}
//			}
//			else if(e.getSource()==btnOutputPathSelect){
//				JFileChooser chooser = new JFileChooser();
//				chooser.setCurrentDirectory(new File(txtOutputPath.getText()));//"/home/GMI/christian.goeschl/prj3/images/test/."));
//				chooser.setDialogTitle("Select Model File");
//				chooser.setFileSelectionMode(JFileChooser.FILES_AND_DIRECTORIES);
//
//				if(chooser.showDialog(null,"Select") == JFileChooser.APPROVE_OPTION)
//				{
//					txtOutputPath.setText(chooser.getSelectedFile().getAbsolutePath());//getCurrentDirectory().getPath());
//				}
//
//			}
//		}
//
//	}
//
//	class LayoutChangeListener implements PropertyChangeListener{
//
//		@Override
//		public void propertyChange(PropertyChangeEvent evt) {
//			if(evt.getPropertyName()=="layoutDone"){
//				try{
//					if((Boolean)evt.getNewValue()){
//						Map<Integer,Point> mLayout=new HashMap<Integer,Point>();
//						Object[][] data=manualLayout.getData();
//						for(int i=0;i<data.length;++i){
//							Point pt=new Point();
//							pt.setLocation((Integer)data[i][1],(Integer)data[i][2]);
//							mLayout.put((Integer)data[i][0],pt);
//						}
//						spatialLayout=new SpatialLayout(Integer.parseInt(txtLayoutCols.getText()),Integer.parseInt(txtLayoutRows.getText()));
//						spatialLayout.setLayout(mLayout);
//
//						manualLayout=null;
//						ledPlateLayoutRed.off();
//						ledPlateLayoutYellow.on();
//					}
//					else{
//						log.warning("error creating manual plate layout");
//						spatialLayout=null;
//						ledPlateLayoutRed.on();
//					}
//				}
//				finally {
//					manualLayout=null;
//					frame.setCursor(Cursor.getDefaultCursor());
//				}
//			}
//		}
//
//	}

}


